
DROP TABLE IF EXISTS transaction_notes;
DROP TABLE IF EXISTS transaction_log;
DROP TABLE IF EXISTS transaction;
DROP TABLE IF EXISTS transaction_accounts;
DROP TABLE IF EXISTS transaction_rates;
DROP TABLE IF EXISTS transaction_currencies;

DROP TABLE IF EXISTS user_payment;
DROP TABLE IF EXISTS transaction_payment_methods;


/**
 * Currencies and rates
 */

CREATE TABLE transaction_currencies (
    id INT NOT NULL PRIMARY KEY AUTO_INCREMENT, 
    is_active BOOLEAN NOT NULL DEFAULT true,
    is_create_on_register BOOLEAN NOT NULL DEFAULT true,
    is_auto_create BOOLEAN NOT NULL DEFAULT true,
    is_crypto BOOLEAN NOT NULL DEFAULT false,
    current_rate DECIMAL(16,8) NOT NULL DEFAULT 0, 
    abbr VARCHAR(10) NOT NULl unique,
    name VARCHAR(255) NOT NULL,
    adapter VARCHAR(255) NOT NULL DEFAULT '', 
    updated_at TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP
);

INSERT INTO transaction_currencies (abbr,name) VALUES ('USD', 'US Dollar');

CREATE TABLE transaction_rates (
    id INT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    abbr VARCHAR(10) NOT NULL,
    rate DECIMAL(16,8) NOT NULL,
    created_at TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (abbr) REFERENCES transaction_currencies (abbr) ON DELETE CASCADE
);

/**
 * Accounts
 */

CREATE TABLE transaction_accounts (
    id INT NOT NULL PRIMARY KEY AUTO_INCREMENT, 
    is_active BOOLEAN NOT NULL DEFAULT true,
    is_deleted BOOLEAN NOT NULL DEFAULT false,
    is_crypto BOOLEAN NOT NULL DEFAULT false,
    uuid VARCHAR(30) NOT NULL,
    currency VARCHAR(10) NOT NULL DEFAULT 'USD', 
    balance DECIMAL(16,8) NOT NULL DEFAULT 0, 
    frozen DECIMAL(16,8) NOT NULL DEFAULT 0, 
    pending DECIMAL(16,8) NOT NULL DEFAULT 0, 
    created_at TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP, 
    updated_at TIMESTAMP,
    label VARCHAR(100) NOT NULL DEFAULT '', 
    FOREIGN KEY (uuid) REFERENCES armor_users (uuid) ON DELETE CASCADE,
    FOREIGN KEY (currency) REFERENCES transaction_currencies (abbr) ON DELETE CASCADE
);

CREATE TABLE transaction (
    id INT NOT NULL PRIMARY KEY AUTO_INCREMENT, 
    account_id INT NOT NULL DEFAULT 0,  
    uuid VARCHAR(30) NOT NULL,
    status VARCHAR(25) NOT NULL DEFAULT 'pending', 
    adapter VARCHAR(255) NOT NULL DEFAULT 'system', 
    index_id INT NOT NULL DEFAULT 0, 
    reference_id INT NOT NULL DEFAULT 0, 
    currency VARCHAR(10) NOT NULL DEFAULT 'USD', 
    from_currency VARCHAR(10) NOT NULL DEFAULT 'USD',  
    amount DECIMAL(16,8) NOT NULL,
    from_amount DECIMAL(16,8) NOT NULL DEFAULT 0, 
    base_amount DECIMAL(16,8) NOT NULL DEFAULT 0, 
    fee DECIMAL(16,8) NOT NULL DEFAULT 0, 
    fee_percent DECIMAL(5,2) NOT NULL DEFAULT 0, 
    payment_id INT NOT NULL DEFAULT 0, 
    ip_address VARCHAR(60) NOT NULL DEFAULT '',
    description VARCHAR(100) NOT NULL DEFAULT '',
    created_at TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP, 
    updated_at TIMESTAMP,
    FOREIGN KEY (account_id) REFERENCES transaction_accounts (id) ON DELETE CASCADE,
    FOREIGN KEY (uuid) REFERENCES armor_users (uuid) ON DELETE CASCADE,
    FOREIGN KEY (currency) REFERENCES transaction_currencies (abbr) ON DELETE CASCADE
);

CREATE TABLE transaction_notes (
    id INT NOT NULL PRIMARY KEY AUTO_INCREMENT, 
    trans_id INT NOT NULL, 
    uuid VARCHAR(30) NOT NULL,
    created_at TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP, 
    note TEXT NOT NULL, 
    FOREIGN KEY (trans_id) REFERENCES transaction (id) ON DELETE CASCADE
);



/**
 * Payment methods
 */

CREATE TABLE transaction_payment_methods (
    id INT NOT NULL PRIMARY KEY AUTO_INCREMENT, 
    is_active BOOLEAN NOT NULL DEFAULT true,
    total_users INT NOT NULL DEFAULT 0,  
    method ENUM('deposit','withdraw') NOT NULL, 
    adapter VARCHAR(255) NOT NULL,
    min_amount DECIMAL(16,8) NOT NULL DEFAULT 0, 
    max_amount DECIMAL(16,8) NOT NULL DEFAULT 0, 
    fee_percent DECIMAL(4,2) NOT NULL DEFAULT 0, 
    processing_time VARCHAR(50) NOT NULL DEFAULT '', 
    name VARCHAR(100) NOT NULL,
    instructions TEXT NOT NULL,  
    instruction_vars TEXT NOT NULL, 
    account_info TEXT NOT NULL
);

CREATE TABLE user_payment (
    id INT NOT NULL PRIMARY KEY AUTO_INCREMENT, 
    is_active BOOLEAN NOT NULL DEFAULT true,
    is_default BOOLEAN NOT NULL DEFAULT false,
    method ENUM('deposit','withdraw') NOT NULL, 
    uuid VARCHAR(30) NOT NULL,
    method_id INT NOT NULL,
    total_tx INT NOT NULL DEFAULT 0, 
    total_amount DECIMAL(16,8) NOT NULL DEFAULT 0, 
    created_at TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP, 
    updated_at TIMESTAMP,
    label VARCHAR(100) NOT NULL DEFAULT '', 
    account_data_id INT NOT NULL, 
    FOREIGN KEY (uuid) REFERENCES armor_users (uuid) ON DELETE CASCADE,
    FOREIGN KEY (method_id) REFERENCES transaction_payment_methods (id) ON DELETE CASCADE
);


