
/**
 * Admins
 */

CREATE TABLE admin (
    uuid VARCHAR(30) NOT NULL PRIMARY KEY, 
    language VARCHAR(5) NOT NULL DEFAULT 'en', 
    timezone VARCHAR(5) NOT NULL DEFAULT 'EST',  
    full_name VARCHAR(100) NOT NULL DEFAULT '', 
    FOREIGN KEY (uuid) REFERENCES armor_users (uuid) ON DELETE CASCADE  
);

/**
 * CMS
 */

CREATE TABLE cms_menus ( 
    id INT NOT NULL PRIMARY KEY AUTO_INCREMENT, 
    package VARCHAR(100) NOT NULL, 
    area VARCHAR(50) NOT NULL DEFAULT 'members', 
    is_active BOOLEAN NOT NULL DEFAULT true, 
    is_system BOOLEAN NOT NULL DEFAULT true,
    require_login BOOLEAN NOT NULL DEFAULT false, 
    require_nologin BOOLEAN NOT NULL DEFAULT false, 
    order_num SMALLINT NOT NULL DEFAULT 0, 
    type ENUM('internal','external','parent','header') NOT NULL DEFAULT 'internal', 
    icon VARCHAR(100) NOT NULL DEFAULT '', 
    position VARCHAR(100) NOT NULL DEFAULT 'bottom', 
    parent VARCHAR(100) NOT NULL DEFAULT '', 
    alias VARCHAR (100) NOT NULL, 
    name VARCHAR(100) NOT NULL, 
    url VARCHAR(255) NOT NULL DEFAULT '' 
);

CREATE TABLE cms_menus_acl (
    id INT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    uuid VARCHAR(30) NOT NULL,
    group_id INT NOT NULL DEFAULT 0,
    area VARCHAR(20) NOT NULL DEFAULT 'admin',
    parent VARCHAR(100) NOT NULL,
    alias VARCHAR(100) NOT NULL
);

CREATE TABLE internal_boxlists (
    id INT NOT NULL PRIMARY KEY AUTO_INCREMENT,  
    package VARCHAR(100) NOT NULL,
    alias VARCHAR(100) NOT NULL, 
    order_num SMALLINT NOT NULL DEFAULT 0,
    position VARCHAR(100) NOT NULL DEFAULT 'bottom',  
    href VARCHAR(100) NOT NULL, 
    title VARCHAR(100) NOT NULL, 
    description TEXT NOT NULL
);

CREATE TABLE internal_email_notifications (
    id INT NOT NULL PRIMARY KEY AUTO_INCREMENT, 
    is_active BOOLEAN NOT NULL DEFAULT true,
    controller VARCHAR(255) NOT NULL, 
    alias VARCHAR(100) NOT NULL DEFAULT '',
    sender VARCHAR(30) NOT NULL, 
    recipient VARCHAR(30) NOT NULL, 
    reply_to VARCHAR(100) NOT NULL DEFAULT '',  
    cc VARCHAR(100) NOT NULL DEFAULT '', 
    bcc VARCHAR(100) NOT NULL DEFAULT '',  
    subject VARCHAR(255) NOT NULL,
    text_contents LONGTEXT NOT NULL, 
    html_contents LONGTEXT NOT NULL,
    condition_vars TEXT NOT NULL
);

CREATE TABLE internal_email_notifications_attachments (
    id INT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    notification_id INT NOT NULL,
    filename VARCHAR(255) NOT NULL,
    filesize INT NOT NULL,
    contents LONGTEXT NOT NULL,
    FOREIGN KEY (notification_id) REFERENCES internal_email_notifications (id) ON DELETE CASCADE
);

CREATE TABLE internal_email_notifications_queue (
    id INT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    is_pending BOOLEAN NOT NULL DEFAULT true,
    total_sent INT NOT NULL DEFAULT 0,
    opens INT NOT NULL DEFAULT 0,
    clicks INT NOT NULL DEFAULT 0,
    mhash VARCHAR(10) NOT NULL UNIQUE,
    sent_by CHAR(255) NOT NULL,
    sender VARCHAR(30) NOT NULL,
    reply_to VARCHAR(255) not null,
    send_date DATETIME NOT NULL,
    adapter VARCHAR(255) NOT NULL,
    subject VARCHAR(255) NOT NULL,
    attach_filename VARCHAR(255) NOT NULL DEFAULT '',
    attach_contents LONGTEXT NOT NULL,
    text_message LONGTEXT NOT NULL,
    html_message LONGTEXT NOT NULL,
    condition_vars LONGTEXT NOT NULL,
    started_at TIMESTAMP,
    completed_at TIMESTAMP
);

CREATE TABLE internal_email_notifications_actions (
    id INT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    mhash VARCHAR(10) NOT NULL,
    link_hash VARCHAR(10) NOT NULL DEFAULT '',
    action VARCHAR(10) NOT NULL,
    ip_address VARCHAR(60) NOT NULL,
    tracking_id VARCHAR(30) NOT NULL DEFAULT '',
    created_at TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (mhash) REFERENCES internal_email_notifications_queue(mhash) ON DELETE CASCADE
);

CREATE TABLE internal_email_notifications_links (
    id INT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    link_hash VARCHAR(10) NOT NULL UNIQUE,
    url VARCHAR(255) NOT NULL
);

/**
 * Alerts
 */

CREATE TABLE alerts (
    id INT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    is_read BOOLEAN NOT NULL DEFAULT false,
    type VARCHAR(15) NOT NULL DEFAULT 'alert',
    uuid VARCHAR(30) NOT NULL,
    sender VARCHAR(30) NOT NULL DEFAULT '',
    badge VARCHAR(100) NOT NULL DEFAULT '',
    url VARCHAR(255) NOT NULL DEFAULT '',
    title VARCHAR(255) NOT NULL DEFAULT '',
    contents TEXT NOT NULL,
    created_at TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    read_at TIMESTAMP,
    FOREIGN KEY (uuid) REFERENCES armor_users (uuid) ON DELETE CASCADE
);

/**
 * Dashboards
 */

CREATE TABLE dashboard_profiles (
    id INT NOT NULL PRIMARY KEY AUTO_INCREMENT,
    is_default BOOLEAN NOT NULL DEFAULT false,
    area VARCHAR(30) NOT NULL DEFAULT 'admin',
    uuid VARCHAR(30) NOT NULL DEFAULT ''
);

INSERT INTO dashboard_profiles VALUES (1, true, 'admin', '');
INSERT INTO dashboard_profiles VALUES (2, true, 'members', '');

CREATE TABLE dashboard_profiles_items (
    id INT NOT NULL PRIMARY KEY AUTO_INCREMENT, 
    profile_id INT NOT NULL, 
    type VARCHAR(10) NOT NULL, 
    class_name VARCHAR(255) NOT NULL,
    FOREIGN KEY (profile_id) REFERENCES dashboard_profiles (id) ON DELETE CASCADE
);




