<?php
declare(strict_types = 1);

namespace App\Cms\Opus\DataTables;

use Apex\Svc\{App, Db, Convert};
use Apex\App\Interfaces\Opus\DataTableInterface;

/**
 * Data Table - Mens
 */
class Menus implements DataTableInterface
{

    // Columns
    public array $columns = [
        'delete' => 'Delete',
        'uri' => 'URI',
        'order' => 'Order',
        'name' => 'Title',
        'is_active' => 'Active',
        'manage' => 'Manage'
    ];
    public array $sortable = [];

    // Other variables
    public int $rows_per_page = 100;
    public bool $has_search = false;

    // Form field (left-most column)
    public string $form_field = 'none';
    public string $form_name = 'men_id';
    public string $form_value = 'id'; 

    /**
     * Constructor
     *
     * All attributes within the <s:function> tag are passed to this method during instantiation, 
     * and here you can define various properties (ie. userid, type, et al) to be used in below methods.
     */
    public function __construct(
        private array $attr, 
        private App $app, 
        private Db $db,
        private Convert $convert
    ) { 
        $this->area = $attr['area'] ?? 'public';
    }

    /**
     * Get total rows in data set - used for pagination.
     */
    public function getTotal(string $search_term = ''):int 
    {

        // Get total
        $total = $this->db->getField("SELECT count(*) FROM cms_menus WHERE area = %s", $this->area);

        // Return
        return (int) $total;
    }

    /**
     * Get rows to display on current page.
     *
     * Should return an array with each element being an associative array representing one table row.
     */ 
    public function getRows(int $start = 0, string $search_term = '', string $order_by = 'order_num asc'):array 
    {

        // Set vars
        $prefix = "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;";
        $results = [];

        // Get parent menus
        $rows = $this->db->query("SELECT * FROM cms_menus WHERE area = %s AND parent = '' ORDER BY order_num", $this->area);
        foreach ($rows as $row) { 

            // Set vars
            $row['uri'] = '/' . $row['alias'];
            $row['order'] = "<input type=\"text\" name=\"order_" . $row['id'] . "\" value=\"$row[order_num]\" style=\"width: 50px;\">";
            $row['delete'] = $row['is_system'] == 1 ? '' : "<center><input type=\"checkbox\" name=\"delete[]\" value=\"$row[id]\"></center>";

            // Is active
            $chk = $row['is_active'] == 1 ? 'checked="checked"' : '';
            $row['is_active'] = "<center><input type=\"checkbox\" name=\"is_active[]\" value=\"$row[id]\" $chk></center>";
            $row['manage'] = "<center><a href=\"/admin/cms/menus_manage?menu_id=$row[id]\" class=\"btn btn-primary btn-sm\">Manage</a></center>";
            array_push($results, $row);

            // Go through child menus
            $crows = $this->db->query("SELECT * FROM cms_menus WHERE area = %s AND parent = %s ORDER BY order_num", $this->area, $row['alias']);
            foreach ($crows as $crow) { 

                // Set variables
                $crow['uri'] = $prefix . '/' . $row['alias'] . '/' . $crow['alias'];
                $crow['order'] = $prefix . "<input type=\"text\" name=\"order_" . $crow['id'] . "\" value=\"$crow[order_num]\" style=\"width: 50px;\">";
                $crow['delete'] = $crow['is_system'] == 1 ? '' : "<center><input type=\"checkbox\" name=\"delete[]\" value=\"$crow[id]\"></center>";
                $chk = $crow['is_active'] == 1 ? 'checked="checked"' : '';
                $crow['is_active'] = "<center><input type=\"checkbox\" name=\"is_active[]\" value=\"$crow[id]\" $chk></center>";
                $crow['manage'] = "<center><a href=\"/admin/cms/menus_manage?menu_id=$crow[id]\" class=\"btn btn-primary btn-sm\">Manage</a></center>";
                array_push($results, $crow);
            }
        }

        // Return
        return $results;
    }

    /**
     * Format individual row for display to browser.
     */
    public function formatRow(array $row):array
    {


        // Return
        return $row;
    }

}

