<?php
declare(strict_types = 1);

namespace App\Cms\Opus\DataTables;

use Apex\Svc\{App, Db, Convert};
use Apex\App\Interfaces\Opus\DataTableInterface;

/**
 * Data Table - PageLayouts
 */
class PageLayouts implements DataTableInterface
{

    // Columns
    public array $columns = [
        'uri' => 'URI',
        'layout' => 'Layout'
    ];
    public array $sortable = [];

    // Other variables
    public int $rows_per_page = 100;
    public bool $has_search = false;

    // Form field (left-most column)
    public string $form_field = 'none';
    public string $form_name = 'page_layout_id';
    public string $form_value = 'id'; 

    /**
     * Constructor
     *
     * All attributes within the <s:function> tag are passed to this method during instantiation, 
     * and here you can define various properties (ie. userid, type, et al) to be used in below methods.
     */
    public function __construct(
        private array $attr, 
        private App $app, 
        private Db $db,
        private Convert $convert
    ) { 
        $config = $app->getRoutesConfig('site.yml');
        $this->layouts = $config['page_vars']['layouts'];

        // Create layout options
        $this->options = [];
        $layout_dir = SITE_PATH . '/views/themes/' . $config['themes']['default'] . '/layouts';
        if (is_dir($layout_dir)) {
            $files = scandir($layout_dir);
            foreach ($files as $file) {

                if (!preg_match("/^(.+)\.html$/", $file, $m)) {
                    continue;
                }
                $this->options[$m[1]] = $convert->case($m[1], 'phrase');
            }
        }

    }

    /**
     * Get total rows in data set - used for pagination.
     */
    public function getTotal(string $search_term = ''):int 
    {
        return 1;
    }

    /**
     * Get rows to display on current page.
     *
     * Should return an array with each element being an associative array representing one table row.
     */ 
    public function getRows(int $start = 0, string $search_term = '', string $order_by = 'id asc'):array 
    {

        // Go through rows
        $results = [];
        foreach ($this->layouts as $uri => $layout) {
            $layout = preg_replace("/\.html$/", '', $layout);

            $options = '';
            foreach ($this->options as $key => $value) {
                $chk = $key == $layout ? 'selected="selected"' : '';
                $options .= "<option value=\"$key\" $chk>$value</option>";
            }

            $results[] = [
                'uri' => $uri,
                'layout' => "<s:select name=\"layout_$uri\">$options</s:select>"
            ];
        }

        // Return
        return $results;
    }

    /**
     * Format individual row for display to browser.
     */
    public function formatRow(array $row):array
    {


        // Return
        return $row;
    }

}

