<?php
declare(strict_types = 1);

namespace App\Cms\Opus\DataTables;

use Apex\Svc\{App, Db, Convert};
use Apex\App\Interfaces\Opus\DataTableInterface;

/**
 * Data Table - PageTitles
 */
class PageTitles implements DataTableInterface
{

    // Columns
    public array $columns = [
            'uri' => 'URI',
            'title' => 'Page Title'
    ];
    public array $sortable = [''];

    // Other variables
    public int $rows_per_page = 100;
    public bool $has_search = false;

    /**
     * Constructor
     *
     * All attributes within the <s:function> tag are passed to this method during instantiation, 
     * and here you can define various properties (ie. userid, type, et al) to be used in below methods.
     */
    public function __construct(
        private array $attr, 
        private App $app, 
        private Db $db,
        private Convert $convert
    ) { 
        $config = $app->getRoutesConfig('site.yml');
        $this->titles = $config['page_vars']['title'];
    }

    /**
     * Get total rows in data set - used for pagination.
     */
    public function getTotal(string $search_term = ''):int 
    {
        return 1;
    }

    /**
     * Get rows to display on current page.
     *
     * Should return an array with each element being an associative array representing one table row.
     */ 
    public function getRows(int $start = 0, string $search_term = '', string $order_by = 'id asc'):array 
    {

        // Go through rows
        $results = [];
        foreach ($this->titles as $uri => $title) {
            $results[] = [
                'uri' => $uri,
                'title' => "<s:textbox name=\"title_$uri\" value=\"$title\">"
            ];
        }

        // Return
        return $results;
    }

    /**
     * Format individual row for display to browser.
     */
    public function formatRow(array $row):array
    {


        // Return
        return $row;
    }

}

