<?php
declare(strict_types = 1);

namespace App\Cms\Opus\Forms;

use Apex\Svc\Db;
use Apex\App\Base\Web\Utils\FormBuilder;
use Apex\App\Interfaces\Opus\FormInterface;

/**
 * Form - Menu
 */
class Menu implements FormInterface
{

    /**
     * Whether or not to pre-populate form fields with POSTed data.
     */
    public bool $allow_post_values = false;


    #[Inject(FormBuilder::class)]
    private FormBuilder $builder;

    #[Inject(Db::class)]
    private Db $db;

    /**
     * Get form fields.
     */
    public function getFields(array $attr = []):array
    {

        // Initialize
        $builder = $this->builder;

        // Set form fields
        $form_fields = [
            'area' => $builder->select()->required()->value('public')->dataSource('hash.cms.menu_areas'),
            'alias' => $builder->textbox()->required()->label('Alias / URI'),
            'name' => $builder->textbox()->required()->label('Page Title'),
            'require_login' => $builder->boolean()->required()->value(false)->label('Require Login?'),
            'require_nologin' => $builder->boolean()->required()->value(false)->label('Require No Login?'),
            'order_num' => $builder->textbox()->value('0')->label('Order')->width('60px'),
            'type' => $builder->select()->required()->value('internal')->dataSource('hash.cms.menu_types'),
            'sep_optional' => $builder->seperator('Optional'),
            'icon' => $builder->textbox()->value(''),
            'parent' => $builder->textbox()->label('Parent Alias / URI'),
            'url' => $builder->textbox()->label('External URL'),
            'submit' => $builder->createOrUpdateButton('Menu', $attr)
        ];

        // Return
        return $form_fields;
    }

    /**
     * Get record
     */
    public function getRecord(string $record_id):array
    {

        // Get row
        if (!$row = $this->db->getIdRow('cms_menus', $record_id)) { 
            $row = [];
        }

        // Return
        return $row;
    }

    /**
     * Validate
     */
    public function validate(array $attr = []):bool
    {

        // Return
        return true;
    }

}

