<?php
declare(strict_types = 1);

namespace App\HttpControllers;

use Apex\Svc\View;
use Apex\Armor\Armor;
use Nyholm\Psr7\Response;
use Psr\Http\Message\{ServerRequestInterface, ResponseInterface};
use Psr\Http\Server\{MiddlewareInterface, RequestHandlerInterface};

/**
 * Http Controller - MembersArea
 */
class MembersArea implements MiddlewareInterface
{

    #[Inject(View::class)]
    private View $view;

    #[Inject(Armor::class)]
    private Armor $armor;

    /**
     * Process request
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $app): ResponseInterface
    {

        // Check auth
        if (!$session = $this->armor->checkAuth()) { 
            $response = (new Response())->withAddedHeader('Location', '/login');
            return $response;
        }

        // Set session
        $app->setArea('members', true);
        $app->setSession($session);
        $app->setUser($session->getUser());

        // Get profile array
        $profile = $app->getUser()->toDisplayArray();
        $this->view->assign('profile', $profile);

        // Render template via auto-routing based on URI being viewed
        $html = $this->view->render();

        // Create PSR7 compliant response
        $response = new Response(
            body: $html
        );

        // Return
        return $response;
    }

}




