<?php
declare(strict_types = 1);

namespace App\HttpControllers\Webapp;

use Apex\Armor\Armor;
use Apex\App\Base\Web\Components;
use Nyholm\Psr7\Response;
use Psr\Http\Message\{ServerRequestInterface, ResponseInterface};
use Psr\Http\Server\{MiddlewareInterface, RequestHandlerInterface};
use Apex\App\Exceptions\ApexComponentNotExistsException;

/**
 * Http Controller - Ajax
 */
class Ajax implements MiddlewareInterface
{

    #[Inject(Components::class)]
    private Components $components;

    #[Inject(Armor::class)]
    private Armor $armor;

    /**
     * Process request
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $app): ResponseInterface
    {

        // Set content type to JSON
        $app->setContentType('application/json');

        // Get auth type / area
        $auth_type = $app->post('auth_type', 'user');
        if ($auth_type == 'admin') { 
            $app->setArea('admin');
        }

        // Check authentication
        if ($session = $this->armor->checkAuth($auth_type)) {
            $app->setSession($session);
        }

        // Parse path
        $parts = explode('/', $app->getPath());
        array_splice($parts, 0, 2);

        // Ensure proper package and alias
        if (count($parts) < 2) { 
            throw new ApexComponentNotExistsException("No AJAX alias defined.");
        }
        $ajax_alias = $parts[0] . '.' . $parts[1];

        // Load the AJAX function class
        if (!$client = $this->components->load('Ajax', $ajax_alias)) { 
            throw new ApexComponentNotExistsException("The AJAX function does not exist with alias, $ajax_alias");
        }

        // Process the AJAX function
        $response = $client->process();

        // Set response, if not autosuggest search
        if ($parts[0] != 'webapp' || $parts[1] != 'search_auto_complete') { 
            $response = [
                'status' => 'ok',
                'actions' => $client->results
            ];
        }

        // Create PSR7 compliant response
        $response = (new Response(
            body: json_encode($response)
        ))->withAddedHeader('Content-type', 'application/json');

        // Return
        return $response;
    }


}


