<?php
declare(strict_types = 1);

namespace App\HttpControllers\Webapp;

use Apex\Svc\{View, Container};
use Apex\Armor\User\Verify\VerifyEmail;
use Nyholm\Psr7\Response;
use Psr\Http\Message\{ServerRequestInterface, ResponseInterface};
use Psr\Http\Server\{MiddlewareInterface, RequestHandlerInterface};
use Apex\App\Attr\Inject;

/**
 * Http controller to verify user e-mail addresses.
 */
class VerifyEmailLink implements MiddlewareInterface
{

    #[Inject(View::class)]
    private View $view;

    #[Inject(Container::class)]
    private Container $cntr;

    /**
     * Process request
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $app): ResponseInterface
    {

        // Verify
        $hash = $app->pathParam('hash');
        $client = $this->cntr->make(VerifyEmail::class);
        if (!$uuid = $client->verify($hash)) {
            $template_file = 'verify_email_fail';
        } else { 
            $template_file = 'verify_email_success';
        }

        // Render template
        $html = $this->view->render($template_file);

        // Return
        return new Response(200, [], $html);
    }

}


