<?php
declare(strict_types = 1);

namespace App\MultiAdmins\Opus\DataTables;

use Apex\Svc\{App, Db, Convert};
use Apex\App\Adapters\ArmorAdapter;
use Apex\App\Interfaces\Opus\DataTableInterface;

/**
 * Data Table - Admins
 */
class Admins implements DataTableInterface
{

    // Columns
    public array $columns = [
        'uuid' => 'ID',
        'username' => 'Username',
        'full_name' => 'Full Name',
        'email' => 'E-Mail',
        'manage' => 'Manage'
    ];
    public array $sortable = [];

    // Other variables
    public int $rows_per_page = 25;
    public bool $has_search = false;

    // Form field (left-most column)
    public string $form_field = 'checkbox';
    public string $form_name = 'admin_id';
    public string $form_value = 'uuid'; 


    /**
     * Constructor
     *
     * All attributes within the <s:function> tag are passed to this method during instantiation, 
     * and here you can define various properties (ie. userid, type, et al) to be used in below methods.
     */
    public function __construct(
        private array $attr, 
        private App $app, 
        private Db $db,
        private Convert $convert,
        private ArmorAdapter $armor_adapter
    ) { 

    }

    /**
     * Get total rows in data set - used for pagination.
     */
    public function getTotal(string $search_term = ''):int 
    {

        // Get total
        $total = $this->db->getField("SELECT count(*) FROM admin");

        // Return
        return (int) $total;
    }

    /**
     * Get rows to display on current page.
     *
     * Should return an array with each element being an associative array representing one table row.
     */ 
    public function getRows(int $start = 0, string $search_term = '', string $order_by = 'id asc'):array 
    {

        // Get rows
        $admins = $this->db->getColumn("SELECT uuid FROM admin");

        // Go through rows
        $results = [];
        foreach ($admins as $uuid) {

            // Load user
            if (!$user = $this->armor_adapter->getUuid($this->db, $uuid)) {
                continue;
            }

            // Add to results
            $results[] = [
                'uuid' => $user->getUuid(),
                'username' => $user->getUsername(),
                'full_name' => $user->getFullName(),
                'email' => $user->getEmail(),
                'manage' => "<center><s:button href=\"/admin/settings/admin_manage?admin_id=$uuid\" label=\"Manage\"></center>"
            ];
        }

        // Return
        return $results;
    }

    /**
     * Format individual row for display to browser.
     */
    public function formatRow(array $row):array
    {


        // Return
        return $row;
    }

}

