<?php
declare(strict_types=1);

namespace App\Transaction\Handlers;

use App\Transaction\Models\{Currency, TxAccount};
use App\Transaction\Exceptions\{TxCurrencyNotExistsException, TxCreateAccountException};

/**
 * Tx account handler
 */
class TxAccountHandler
{

    /**
     * Create
     */
    public function create(string $uuid, string $currency, float $balance = 0, string $label = ''):TxAccount
    {

        // Get currency
        if (!$cur = Currency::whereFirst('abbr = %s', $currency)) {
            throw new TxCurrencyNotExistsException("Currency does not exist, $currency");
        } 

        //elseif ($cur->is_auto_create !== true) {
            //throw new TxCreateAccountException("Unable to create account for uuid $uuid with currency $currency as the currency is set to not allow auto creation.");
        //}

        // Add to database
        $acct = TxAccount::insert([
            'uuid' => $uuid,
            'is_crypto' => $cur->is_crypto,
            'currency' => $currency,
            'balance' => $balance,
            'label' => $label
        ]);

        // Return
        return $acct;
    }

    /**
     * Lookup
     */
    public function lookup(string $uuid, string $currency):TxAccount
    {

        // Check for account
        if (null !== ($acct = TxAccount::whereFirst('uuid = %s AND currency = %s AND is_deleted = %b', $uuid, $currency, false))) {
            return $acct;
        }

        // Create account
        $acct = $this->create($uuid, $currency);

        // Return
        return $acct;
    }

}

