<?php
declare(strict_types=1);

namespace App\Transaction\Helpers;

use Apex\Svc\Container;
use Apex\App\Base\Implementors;
use App\Transaction\Enums\TxStatus;
use App\Transaction\Interfaces\{AdapterInterface, AdapterGroupInterface};

/**
 * Adapter form options
 */
class AdapterOptions
{

    #[Inject(Container::class)]
    private Container $cntr;

    #[Inject(Implementors::class)]
    private Implementors $implementors;

    /**
     * Create select options
     */
    public function create(string $selected = ''): string
    {

        // Get groups
        $groups = $this->implementors->getPropertyValues(AdapterGroupInterface::class, 'title');
        $adapters = $this->implementors->getPropertyValues(AdapterInterface::class, 'title');

        // Go through groups
        list($options, $groups_done) = ['', []];
        foreach ($groups as $class_name => $title) {

            // Create options
            $obj = $this->cntr->make($class_name);
            $sub_options = $obj->createSelectOptions($selected);

            // Skip, if needed
            if ($sub_options == '') {
                continue;
            }
            $groups_done[] = $class_name;

            // Add to options
            $options .= "    <optgroup label=\"$title\">\n";
            $options .= $sub_options;
            $options .= "    </optgroup>\n";
        }

        // Add misc options, if needed
        $first = true;
        foreach ($adapters as $class_name => $title) {

            // Load, and check group class
            $obj = $this->cntr->make($class_name);
            if (isset($obj->group_class) && in_array($obj->group_class, $groups_done)) {
                continue;
            }

            // Add optgroup, if  first 
            if ($first === true) {
                $options .= "    <optgroup label=\"Miscellaneous\">\n";
                $first = false;
            }

            // Add option
            $chk = $selected == $class_name ? 'selected="selected"' : '';
            $options .= "        <option value=\"$class_name\" $chk>$title</option>\n";
        }

        // Add ending optgroup, if we have misc
        if ($first === false) {
            $options .= "    </optgroup>\n";
        }

        // Return
        return $options;
    }

    /**
     * Create status options
     */
    public function createStatusOptions(string $selected = ''): string
    {

        // Go through statuses
        $options = '';
        foreach (TxStatus::cases() as $class_name => $vars) {
            $chk = $vars->value == $selected ? 'selected="selected"' : '';
            $name = ucwords(str_replace('_', ' ', $vars->name));
            $options .= "<option value=\"$vars->value\" $chk>$name</option>";
        }

        // Retunr
        return $options;
    }

}


