<?php
declare(strict_types = 1);

namespace App\Transaction\Listeners;

use Apex\Svc\{App, Db};
use Apex\App\Interfaces\ListenerInterface;
use Apex\Cluster\Interfaces\{MessageRequestInterface, FeHandlerInterface};

/**
 * Listener - Users
 */
class Users implements ListenerInterface
{

    /**
     * Routing key for which the listener accepts messages for.
     */
    public static string $routing_key = 'users.profiles';

    #[Inject(App::class)]
    private App $app;

    #[Inject(Db::class)]
    private Db $db;

    /**
     * Load user profile
     */
    public function load(MessageRequestInterface $msg, FeHandlerInterface $handler)
    {

        // Get params
        $uuid = $msg->getParams();

        // Get balances
        if (!$balance = $this->db->getField("SELECT sum(balance) FROM transaction_accounts WHERE uuid = %s AND currency = %s", $uuid, $this->app->config('core.default_currency'))) {
            $balance = 0;
        }

        // Return
        return [
            'balance' => $balance
        ];
    }

}

