<?php
declare(strict_types = 1);

namespace App\Transaction\Models;

use Apex\Svc\{App, Convert};
use Apex\App\Base\Model\MagicModel;
use App\Transaction\Models\Currency;
use DateTime;

/**
 * TxAccount Model
 */
class TxAccount extends MagicModel
{

    #[Inject(App::class)]
    protected App $app;

    #[Inject(Convert::class)]
    protected Convert $convert;

    /**
     * Database table
     *
     * @var string
     */
    protected static string $dbtable = 'transaction_accounts';

    /**
     * Constructor
     */
    public function __construct(
        protected int $id = 0,
        protected bool $is_active = true, 
        protected bool $is_deleted = false,
        protected bool $is_crypto = false, 
        protected string $uuid = '', 
        protected string $currency = 'USD', 
        protected float | string $balance = 0.000000,
        protected float | string $frozen = 0.00000000, 
        protected float | string $pending = 0.00000000, 
        protected ?DateTime $created_at = null, 
        protected ?DateTime $updated_at = null, 
        protected string $label = ''
    ) { 

    }

    /**
     * Get Currency
     */
    public function getCurrency():Currency
    {
        $obj = Currency::whereFirst('abbr = %s', $this->currency);
        return $obj;
    }

    /**
     * Get balance
     */
    public function getBalance():float | string
    {
        if (is_string($this->balance)) {
            return bcadd($this->balance, (string) $this->frozen);
        } else {
            return $this->balance + $this->frozen;
        }

    }

    /**
     * toDisplayArray
     */
    public function toDisplayArray(bool $format_all_amounts = false): array
    {

        // Get currency
        $currency = $this->getCurrency();
        $label = $this->label == '' ? $currency->name : $this->label;
        $balance_available = $this->getBalance();

        // Set vars
        $vars = [
            'id' => $this->id,
            'currency' => $this->currency,
            'currency_name' => $currency->name,
            'rate' => $this->convert->money($currency->current_rate, $this->app->config('core.default_currency')),
            'label' => $label,
            'display_name' => $label . ' (' . $this->convert->money($balance_available, $this->currency) . ')',
            'balance' => $this->convert->money($this->balance, $this->currency),
            'balance_available' => $this->convert->money($balance_available, $this->currency),
            'pending' => $this->pending == 0.00000000 ? '-' : $this->convert->money($this->pending, $this->currency),
            'frozen' => $this->frozen == 0.00000000 ? '-' : $this->convert->money($this->frozen, $this->currency)
        ];

        // Full amount
        if ($format_all_amounts === true) {
            $vars['pending'] = $this->convert->money($this->pending, $this->currency);
            $vars['frozen'] = $this->convert->money($this->frozen, $this->currency);
        }

        // Return
        return $vars;
    }

}


