<?php
declare(strict_types = 1);

namespace App\Transaction\Opus\TabControls;

use Apex\Svc\View;
use App\Transaction\Models\TxAccount;
use App\Transaction\Exceptions\TxAccountNotExistsException;
use Apex\App\Interfaces\Opus\TabControlInterface;

/**
 * Tab Control - Account
 */
class Account implements TabControlInterface
{

    // Tab pages
    public array $tab_pages = [
        'Transactions' => 'Transactions',
        'Pending' => 'Pending'
    ];

    /**
     * Constructor
     *
     * All attributes within the <s:function> tag are passed to this method during instantiation, 
     * and here you can define various properties (ie. userid, type, et al) to be used in below methods.
     */
    public function __construct(
        private View $view,
        private array $attr 
    ) { 
        $this->account_id = $attr['account_id'] ?? 0;
    }

    /**
     * Process the tab control
     *
     * This method will be called every time this tab control is displayed, allowing you to 
     * perform any necessary actions to populate the tab control, or process 
     * any submitted forms within it.
     */
    public function process():void
    {

        // Load account
        if (!$acct = TxAccount::whereId($this->account_id)) {
            throw new TxAccountNotExistsException("No transaction account exists with id# $this->account_id");
        }

        // Format
        $vars = $acct->toDisplayArray(true);
        $this->view->assign('account', $vars);
    }

}



