<?php
declare(strict_types = 1);

namespace App\Users\Helpers;

use Apex\Svc\Db;
use Apex\App\Base\Model\ModelIterator;
use App\Users\User;

/**
 * Filter criteria
 *
 * Uses the values submitted from the App\Users\Opus\Forms\BroadcastCriteria smart form, 
 * and returns a ModelIterator object of all users who match the criteria.
 *
 * Used for functionality such as broadcast e-mail / SMS to all users.
 */
class FilterCriteria
{

    #[Inject(Db::class)]
    private Db $db;

    /**
     * Filter
     */
    public function filter(array $criteria, int $offset = 0):?ModelIterator
    {

        // Get is_deleted
        $is_deleted = $criteria['is_deleted'] ?? 0;
        $is_deleted = $is_deleted == 1 ? true : false;

        // Start SQL
        $sql = "SELECT * FROM armor_users u, user_profiles p WHERE u.uuid = p.uuid AND u.is_deleted = %b";
        $args[] = $is_deleted;

        // Booleans
        foreach (['is_active', 'email_verified', 'phone_verified'] as $var) {
            $value = $criteria[$var] ?? '';
            if ($value != '') {
                $sql .= " AND u.$var = %b";
                $args[] = (bool) $value;
            }
        }

        // Add group id
        $groups = isset($criteria['group_id']) && is_array($criteria['group_id']) ? $criteria['group_id'] : [];
        if (count($groups) > 0) {
            $sql .= " AND p.group_id IN (" . implode(',', $groups) . ')';
        }

        // Finish SQL
        $sql .= " ORDER BY u.created_at";
        if ($offset > 0) {
            $sql .= " OFFSET $offset";
        }
        $stmt = $this->db->query($sql, ...$args);

        // Create ModelIterator
        $iterator = new ModelIterator(
            stmt: $stmt,
            class_name: User::class
        );

        // Return
        return $iterator;
    }

}


