<?php
declare(strict_types = 1);

namespace App\Users\Opus\DashboardItems;

use Apex\Svc\{App, View};
use Apex\App\Interfaces\Opus\DashboardItemInterface;

/**
 * Dashboard item - LoginHistoryTab
 */
class LoginHistoryTab implements DashboardItemInterface
{

    /**
     * The type of dashboard item.
     * Can be either:  top, right, tab
     */
    public string $type = 'tab';

    /**
     * The area this dashboard item is available.  
     * Generally will only ever be either 'admin' or 'members'.
     */
    public string $area = 'members';

    /**
     * Whether or not to activate this dashboard item upon initial installation
     */
    public bool $is_default = true;

    /**
     * The title of the dashboard item.
     */
    public string $title = 'Login History';

    /**
     * The div id and panel class name of the dashboard item.
     * Only applicable for items with $type of 'top'.
     */
    public string $divid = 'members-online';
    public string $panel_class = 'panel bg-teal-400';

    #[Inject(App::class)]
    private App $app;

    #[Inject(View::class)]
    private View $view;

    /**
     * Render the dashboard item.
     *
     * @return The HTML contents of the dashboard item.
     */
    public function render():string
    {

        // Set html
        $html = "<h3>Login History</h3>\n";
        $html .= "<p>Below shows your most recent logins.</p>\n";
        $html .= "<s:function alias=\"display_table\" table=\"webapp.login_history\" uuid=\"" . $this->app->getUuid() . "\">\n";

        // Return
        return $this->view->renderBlock($html);
    }

}


