<?php
declare(strict_types = 1);

namespace App\Users\Opus\DashboardItems;

use Apex\Svc\View;
use Apex\App\Interfaces\Opus\DashboardItemInterface;

/**
 * Dashboard item - NewUsersTab
 */
class NewUsersTab implements DashboardItemInterface
{

    #[Inject(View::class)]
    private View $view;

    /**
     * The type of dashboard item.
     * Can be either:  top, right, tab
     */
    public string $type = 'tab';

    /**
     * The area this dashboard item is available.  
     * Generally will only ever be either 'admin' or 'members'.
     */
    public string $area = 'admin';

    /**
     * Whether or not to activate this dashboard item upon initial installation
     */
    public bool $is_default = true;

    /**
     * The title of the dashboard item.
     */
    public string $title = 'New Users';

    /**
     * The div id and panel class name of the dashboard item.
     * Only applicable for items with $type of 'top'.
     */
    public string $divid = 'members-online';
    public string $panel_class = 'panel bg-teal-400';


    /**
     * Render the dashboard item.
     *
     * @return The HTML contents of the dashboard item.
     */
    public function render():string
    {

        // Set html
        $html = "<h3>Most Recent User Registrations</h3>\n";
        $html .= "<p>The below table lists the most recent user registrations</p>\n";
        $html .= "<s:function alias=\"display_table\" table=\"users.user_list\" sort_by=\"created_at desc\">\n";

        // Return
        return $this->view->renderBlock($html);
    }

}


