<?php
declare(strict_types = 1);

namespace App\Users\Opus\DashboardItems;

use Apex\Svc\{App, Db};
use Apex\App\Interfaces\Opus\DashboardItemInterface;

/**
 * Dashboard item - UserGroup
 */
class UserGroup implements DashboardItemInterface
{

    /**
     * The type of dashboard item.
     * Can be either:  top, right, tab
     */
    public string $type = 'top';

    /**
     * The area this dashboard item is available.  
     * Generally will only ever be either 'admin' or 'members'.
     */
    public string $area = 'members';

    /**
     * Whether or not to activate this dashboard item upon initial installation
     */
    public bool $is_default = true;

    /**
     * The title of the dashboard item.
     */
    public string $title = 'User Group';

    /**
     * The div id and panel class name of the dashboard item.
     * Only applicable for items with $type of 'top'.
     */
    public string $divid = 'server-load';
    public string $panel_class = 'panel bg-green-400';

    #[Inject(App::class)]
    private App $app;

    #[Inject(Db::class)]
    private Db $db;

    /**
     * Render the dashboard item.
     *
     * @return The HTML contents of the dashboard item.
     */
    public function render():string
    {

        $name = 'Unknown';
        if ($group_id = $this->db->getField("SELECT group_id FROM user_profiles WHERE uuid = %s", $this->app->getUuid())) {
            $name = $this->db->getField("SELECT name FROM user_groups WHERE id = %i", $group_id);
        }

        // Return
        return $name;
    }

}


