<?php
declare(strict_types = 1);

namespace App\Users\Opus\DashboardItems;
use Apex\Svc\{App, Db};
use Apex\App\Interfaces\Opus\DashboardItemInterface;

/**
 * Dashboard item - UserSummary
 */
class UserSummary implements DashboardItemInterface
{

    /**
     * The type of dashboard item.
     * Can be either:  top, right, tab
     */
    public string $type = 'right';

    /**
     * The area this dashboard item is available.  
     * Generally will only ever be either 'admin' or 'members'.
     */
    public string $area = 'admin';

    /**
     * Whether or not to activate this dashboard item upon initial installation
     */
    public bool $is_default = true;

    /**
     * The title of the dashboard item.
     */
    public string $title = 'User Summary';

    /**
     * The div id and panel class name of the dashboard item.
     * Only applicable for items with $type of 'top'.
     */
    public string $divid = 'members-online';
    public string $panel_class = 'panel bg-teal-400';

    #[Inject(App::class)]
    private App $app;

    #[Inject(Db::class)]
    private Db $db;


    /**
     * Render the dashboard item.
     *
     * @return The HTML contents of the dashboard item.
     */
    public function render():string
    {

        // Initialize
        $date = date('Y-m-d H:i:s');

        // Get total users
        $total_users = $this->db->getField("SELECT count(*) FROM user_profiles");
    $total_24hour = $this->db->getField("SELECT count(*) FROM armor_users WHERE type = 'user' AND is_deleted = %b AND created_at >= %s", false, $this->db->subtractTime('hour', 24, $date));
        $total_1week = $this->db->getField("SELECT count(*) FROM armor_users WHERE type = 'user' AND is_deleted = %b AND created_at >= %s", false, $this->db->subtractTime('day', 7, $date));
        $total_1month = $this->db->getField("SELECT count(*) FROM armor_users WHERE type = 'user' AND is_deleted = %b AND created_at >= %s", false, $this->db->subtractTime('month', 1, $date));
        $total_this_month = $this->db->getField("SELECT count(*) FROM armor_users WHERE type = 'user' AND is_deleted = %b AND EXTRACT(year from created_at) = %i AND EXTRACT(month from created_at) = %d", false, date('Y'), date('m'));

        // Set HTML
            $html = '<span class="media-title font-weight-semibold">Total Users: <b>' . $total_users . '</b></span><br />';
        $html .= '<span class="media-title font-weight-semibold">Last 24h: <b>' . $total_24hour . '</b></span><br />';
        $html .= '<span class="media-title font-weight-semibold">Last Week: <b>' . $total_1week . '</b></span><br />';
        $html .= '<span class="media-title font-weight-semibold">Last 30 days: <b>' . $total_1month . '</b></span><br />';
        $html .= '<span class="media-title font-weight-semibold">This Month: <b>' . $total_this_month . '</b></span><br />';

        // Return
        return $html;
    }

}


