<?php
declare(strict_types = 1);

namespace App\Users\Opus\DataTables;

use Apex\Svc\{App, Db, Convert};
use Apex\App\Sys\Utils\Hashes;
use Apex\Armor\User\Extra\UserLog;
use Apex\App\Interfaces\Opus\DataTableInterface;

/**
 * Data Table - ActivityLog
 */
class ActivityLog implements DataTableInterface
{

    // Columns
    public array $columns = [
        'created_at' => 'Date',
        'action' => 'Action',
        'username' => 'User',
        'ip_address' => 'IP Address',
        'old_item' => 'Old Item',
        'new_item' => 'New Item'
    ];
    public array $sortable = ['id'];

    // Other variables
    public int $rows_per_page = 25;
    public bool $has_search = false;

    // Form field (left-most column)
    public string $form_field = 'none';
    public string $form_name = 'activity_log_id';
    public string $form_value = 'id'; 

    /**
     * Constructor
     *
     * All attributes within the <s:function> tag are passed to this method during instantiation, 
     * and here you can define various properties (ie. userid, type, et al) to be used in below methods.
     */
    public function __construct(
        private array $attr, 
        private App $app, 
        private Db $db,
        private UserLog $user_log,
        private Convert $convert,
        private Hashes $hashes
    ) { 
        $this->uuid = $this->attr['uuid'] ?? '';
        if ($this->uuid != '') {
            unset($this->columns['username']);
        }
    }

    /**
     * Get total rows in data set - used for pagination.
     */
    public function getTotal(string $search_term = ''):int 
    {

        // Get total
        if ($this->uuid == '') {
            $total = $this->user_log->getCountAll();
        } else {
            $total = $this->user_log->getCountUuid($this->uuid);
        }

        // Return
        return (int) $total;
    }

    /**
     * Get rows to display on current page.
     *
     * Should return an array with each element being an associative array representing one table row.
     */ 
    public function getRows(int $start = 0, string $search_term = '', string $order_by = 'id asc'):array 
    {

        // List
        if ($this->uuid == '') {
            $rows = $this->user_log->listAll(false, $start, $this->rows_per_page);
        } else {
            $rows = $this->user_log->listUuid($this->uuid, $start, $this->rows_per_page);
        }

        // Go through rows
        $results = [];
        foreach ($rows as $row) { 
            $results[] = $this->formatRow($row);
        }

        // Return
        return $results;
    }

    /**
     * Format individual row for display to browser.
     */
    public function formatRow(array $row):array
    {

        // Initialize
        $user = $row['user'] ?? null;

        // Format
        $date = $row['created_at'];
        $row['username'] = $user === null ? '' : $user->getUsername() . ' (' . $user->getFullName() . ')';
        $row['created_at'] = $this->convert->date($date->format('Y-m-d H:i:s'), true); 
        $row['action'] = $this->hashes->getVar('users.log_action', $row['action']);
        // Return
        return $row;
    }

}

