<?php
declare(strict_types = 1);

namespace App\Users\Opus\DataTables;

use Apex\Svc\{App, Db, Convert};
use Apex\App\Interfaces\Opus\DataTableInterface;
use App\Users\Helpers\UserNotifications;

/**
 * Data Table - EmailHistory
 */
class EmailHistory implements DataTableInterface
{


    // Columns
    public array $columns = [
        'id' => 'ID',
        'total_sent' => 'Sent',
        'opens' => 'Opens',
        'clicks' => 'Clicks',
        'subject' => 'Subject',
        'completed_at' => 'Date Sent',
            'view' => 'View'
    ];
    public array $sortable = ['id', 'total_sent', 'opens', 'clicks', 'subject', 'completed_at'];

    // Other variables
    public int $rows_per_page = 50;
    public bool $has_search = false;

    // Form field (left-most column)
    public string $form_field = 'none';
    public string $form_name = 'history_id';
    public string $form_value = 'id'; 



    /**
     * Constructor
     *
     * All attributes within the <s:function> tag are passed to this method during instantiation, 
     * and here you can define various properties (ie. userid, type, et al) to be used in below methods.
     */
    public function __construct(
        private array $attr, 
        private App $app, 
        private Db $db,
        private Convert $convert
    ) { 

    }

    /**
     * Get total rows in data set - used for pagination.
     */
    public function getTotal(string $search_term = ''):int 
    {

        // Get total
        $total = $this->db->getField("SELECT count(*) FROM internal_email_notifications_queue WHERE adapter = %s", UserNotifications::class);

        // Return
        return (int) $total;
    }

    /**
     * Get rows to display on current page.
     *
     * Should return an array with each element being an associative array representing one table row.
     */ 
    public function getRows(int $start = 0, string $search_term = '', string $order_by = 'id desc'):array 
    {

        // Get rows
        $rows = $this->db->query("SELECT * FROM internal_email_notifications_queue WHERE adapter = %s ORDER BY $order_by LIMIT $start,$this->rows_per_page", UserNotifications::class);

        // Go through rows
        $results = [];
        foreach ($rows as $row) { 
            $results[] = $this->formatRow($row);
        }

        // Return
        return $results;
    }

    /**
     * Format individual row for display to browser.
     */
    public function formatRow(array $row):array
    {

        // Format
        if ($row['completed_at'] === null) {
            $row['completed_at'] = 'Not Sent';
            $row['view'] = '';
        } else {
            $row['completed_at'] = $this->convert->date($row['completed_at'], true);
            $row['view'] = "<center><s:button href=\"/admin/communicate/email_history_view?mhash=$row[mhash]\" label=\"View\"></center>";
        }

        // Return
        return $row;
    }

}

