<?php
declare(strict_types = 1);

namespace App\Users\Opus\DataTables;

use Apex\Svc\{App, Db, Convert};
use Apex\App\Interfaces\Opus\DataTableInterface;

/**
 * Data Table - EmailHistoryActions
 */
class EmailHistoryActions implements DataTableInterface
{

    // Columns
    public array $columns = [
        'created_at' => 'Date',
        'url' => 'URL',
        'username' => 'username',
        'email' => 'E-Mail',
        'manage' => 'Manage'
    ];
    public array $sortable = ['created_at', 'first_name', 'last_name', 'email'];

    // Other variables
    public int $rows_per_page = 50;
    public bool $has_search = false;

    // Form field (left-most column)
    public string $form_field = 'none';
    public string $form_name = 'email_history_action_id';
    public string $form_value = 'id'; 

    /**
     * Constructor
     *
     * All attributes within the <s:function> tag are passed to this method during instantiation, 
     * and here you can define various properties (ie. userid, type, et al) to be used in below methods.
     */
    public function __construct(
        private array $attr, 
        private App $app, 
        private Db $db,
        private Convert $convert
    ) { 
        $this->mhash = $attr['mhash'];
        $this->action = $attr['action'] ?? 'open';

    }

    /**
     * Get total rows in data set - used for pagination.
     */
    public function getTotal(string $search_term = ''):int 
    {

        // Get total
        $total = $this->db->getField("SELECT count(*) FROM internal_email_notifications_actions WHERE mhash = %s AND action = %s", $this->mhash, $this->action);

        // Return
        return (int) $total;
    }

    /**
     * Get rows to display on current page.
     *
     * Should return an array with each element being an associative array representing one table row.
     */ 
    public function getRows(int $start = 0, string $search_term = '', string $order_by = 'created_at desc'):array 
    {

        // Get rows
        $rows = $this->db->query("SELECT a.created_at,a.link_hash,u.uuid,u.username,u.email FROM internal_email_notifications_actions AS a, armor_users AS u WHERE a.mhash = %s AND a.action = %s AND a.tracking_id = u.uuid ORDER BY $order_by LIMIT $start,$this->rows_per_page", $this->mhash, $this->action);

        // Go through rows
        $results = [];
        foreach ($rows as $row) { 
            $results[] = $this->formatRow($row);
        }

        // Return
        return $results;
    }

    /**
     * Format individual row for display to browser.
     */
    public function formatRow(array $row):array
    {

        // Format
        $row['url'] = '';
        $row['created_at'] = $this->convert->date($row['created_at'], true);
        $row['manage'] = "<center><s:button href=\"/admin/users/manage?manage_id=$row[uuid]\" label=\"Manage\"></center>";

        // Get URL, if needed
        if ($this->action == 'click') {
            $url = $this->db->getField("SELECT url FROM internal_email_notifications_links WHERE link_hash = %s", $row['link_hash']);
            $row['url'] = "<a href=\"$url\" target=\"_blank\">$url</a>";
        }

        // Return
        return $row;
    }

}

