<?php
declare(strict_types = 1);

namespace App\Users\Opus\DataTables;

use Apex\Svc\{App, Db, Convert};
use Apex\App\Adapters\ArmorAdapter;
use App\Users\Models\Note;
use Apex\App\Interfaces\Opus\DataTableInterface;

/**
 * Data Table - Notes
 */
class Notes implements DataTableInterface
{

    // Columns
    public array $columns = [
        'created_at' => 'Date',
            'added_by' => 'Added By',
            'note' => 'NOte'
    ];
    public array $sortable = ['id'];

    // Other variables
    public int $rows_per_page = 25;
    public bool $has_search = false;

    // Form field (left-most column)
    public string $form_field = 'none';
    public string $form_name = 'note_id';
    public string $form_value = 'id'; 

    /**
     * Constructor
     *
     * All attributes within the <s:function> tag are passed to this method during instantiation, 
     * and here you can define various properties (ie. userid, type, et al) to be used in below methods.
     */
    public function __construct(
        private array $attr, 
        private App $app, 
        private Db $db,
        private Convert $convert,
        private ArmorAdapter $armor_adapter
    ) { 
        $this->uuid = $this->attr['uuid'] ?? '';
    }

    /**
     * Get total rows in data set - used for pagination.
     */
    public function getTotal(string $search_term = ''):int 
    {
        // Get total
        $total = Note::count('uuid = %s', $this->uuid);
        return (int) $total;
    }

    /**
     * Get rows to display on current page.
     *
     * Should return an array with each element being an associative array representing one table row.
     */ 
    public function getRows(int $start = 0, string $search_term = '', string $order_by = 'id asc'):array 
    {

        // Get rows
        $notes = Note::getUser($this->uuid, $this->rows_per_page, $start);

        // Go through rows
        $results = [];
        foreach ($notes as $note) { 
            $results[] = $this->formatRow($note->toArray());
        }

        // Return
        return $results;
    }

    /**
     * Format individual row for display to browser.
     */
    public function formatRow(array $row):array
    {

        // Format
        $row['created_at'] = $this->convert->date($row['created_at'], true);

        // Get added by
        $user = $this->armor_adapter->getUuid($this->db, $row['added_by']);
        $row['added_by'] = $user->getUsername();

        // Return
        return $row;
    }

}

