<?php
declare(strict_types = 1);

namespace App\Users\Opus\Forms;

use Apex\Svc\Db;
use Apex\App\Base\Web\Utils\FormBuilder;
use Apex\App\Interfaces\Opus\FormInterface;

/**
 * Form - BroadcastCriteria
 */
class BroadcastCriteria implements FormInterface
{

    /**
     * Whether or not to pre-populate form fields with POSTed data.
     */
    public bool $allow_post_values = true;

    #[Inject(FormBuilder::class)]
    private FormBuilder $builder;

    #[Inject(Db::class)]
    private Db $db;

    /**
     * Get form fields.
     */
    public function getFields(array $attr = []):array
    {

        // Initialize
        $builder = $this->builder;

        // Set form fields
        $form_fields = [
            'group_id' => $builder->checkbox()->label('User Group')->dataSource('table.user_groups.~name~.id'),
            'is_active' => $builder->select()->dataSource('hash.core.boolean'),
            'is_deleted' => $builder->select()->dataSource('hash.core.boolean'),
            'email_verified' => $builder->select()->dataSource('hash.core.boolean'),
            'phone_verified' => $builder->select()->dataSource('hash.core.boolean')
        ];

        // Return
        return $form_fields;
    }

    /**
     * Get record
     */
    public function getRecord(string $record_id):array
    {

        // Login notice
        if (preg_match("/^login_notice:(\d+)$/", $record_id, $m)) {
            $criteria = $this->db->getField("SELECT criteria FROM internal_login_notices WHERE id = %i", $m[1]);
            return json_decode($criteria, true);
        }

        // Return
        return [];
    }

    /**
     * Validate
     */
    public function validate(array $attr = []):bool
    {

        // Return
        return true;
    }

}

