<?php
declare(strict_types = 1);

namespace App\Users\Opus\Forms;

use Apex\Svc\Db;
use Apex\App\Base\Web\Utils\FormBuilder;
use Apex\App\Interfaces\Opus\FormInterface;

/**
 * Form - LoginNotouse
 */
class LoginNotice implements FormInterface
{

    /**
     * Whether or not to pre-populate form fields with POSTed data.
     */
    public bool $allow_post_values = false;


    #[Inject(FormBuilder::class)]
    private FormBuilder $builder;

    #[Inject(Db::class)]
    private Db $db;

    /**
     * Get form fields.
     */
    public function getFields(array $attr = []):array
    {

        // Initialize
        $builder = $this->builder;

        // Set form fields
        $form_fields = [
            'is_markdown' => $builder->boolean()->required()->value(true),
            'requires_accept' => $builder->boolean()->required()->value(false),
            'user_type' => $builder->select()->required()->dataSource('hash.users.login_notice_type'),
            'title' => $builder->textbox()->required(),
            'contents' => $builder->textarea()->required()->value(''),
            'submit' => $builder->createOrUpdateButton('Notice', $attr)
        ];

        // Return
        return $form_fields;
    }

    /**
     * Get record
     */
    public function getRecord(string $record_id):array
    {

        // Get row
        if (!$row = $this->db->getIdRow('internal_login_notices', $record_id)) { 
            $row = [];
        }

        // Return
        return $row;
    }

    /**
     * Validate
     */
    public function validate(array $attr = []):bool
    {

        // Return
        return true;
    }

}

