<?php
declare(strict_types = 1);

namespace App\Users\Opus\Forms;

use Apex\Svc\Db;
use Apex\App\Base\Web\Utils\FormBuilder;
use Apex\App\Interfaces\Opus\FormInterface;

/**
 * Form - ProfileField
 */
class ProfileField implements FormInterface
{

    /**
     * Whether or not to pre-populate form fields with POSTed data.
     */
    public bool $allow_post_values = false;


    #[Inject(FormBuilder::class)]
    private FormBuilder $builder;

    #[Inject(Db::class)]
    private Db $db;

    /**
     * Get form fields.
     */
    public function getFields(array $attr = []):array
    {

        // Initialize
        $builder = $this->builder;

        // Set form fields
    $form_fields = [
            'show_in_form' => $builder->boolean()->required()->value(true),
            'order_num' => $builder->textbox()->required()->value(''),
            'form_field' => $builder->select()->required()->dataSource('hash.webapp.form_fields')->value('textbox'),
            'alias' => $builder->textbox()->required()->value(''),
            'default_value' => $builder->textbox()->value(''),
            'name' => $builder->textbox()->required()->value(''),
            'select_options' => $builder->textarea(),
            'submit' => $builder->createOrUpdateButton('Profile Field', $attr)
        ];

        // Remove order num, if needed
        if (!isset($attr['record_id'])) {
            unset($form_fields['order_num']);
        }

        // Return
        return $form_fields;
    }

    /**
     * Get record
     */
    public function getRecord(string $record_id):array
    {

        // Get row
        if (!$row = $this->db->getIdRow('user_profile_fields', $record_id)) { 
            $row = [];
        }

        // Return
        return $row;
    }

    /**
     * Validate
     */
    public function validate(array $attr = []):bool
    {

        // Return
        return true;
    }

}

