<?php
declare(strict_types = 1);

namespace App\Users\Opus\Graphs;

use Apex\Svc\{App, Db};
use Apex\App\Base\Web\Utils\GraphUtils;
use Apex\App\Base\Web\Render\Graph;
use Apex\App\Interfaces\Opus\GraphInterface;

/**
 * Graph - Growth
 */
class Growth extends Graph implements GraphInterface
{

    /**
     * The type of graph.  Supported values are: bar, line, pie
     */
    public string $type = 'line';

    /**
     * The labels of the X and Y axis
     */
    public string $label_yaxis = 'Date';
    public string $label_xaxis = 'Users';

    #[Inject(App::class)]
    protected App $app;

    #[Inject(Db::class)]
    private Db $db;

    #[Inject(GraphUtils::class)]
    protected GraphUtils $graph_utils;


    /**
     * Get graph data
     */
    public function getData(array $attr = []):void
    {

        // initialize
        $period = $this->app->get('period', 'day');
        $user_groups = $this->db->getHash("SELECT id,name FROM user_groups ORDER BY iD");

        // Go through last 15
        $sets = [];
        for ($x=0; $x < 15; $x++) { 

            // Get where SQL
        list($where_sql, $display_date, $date) = $this->graph_utils->getPeriodSql('armor_users.created_at', $x, $period, '', true);

            // Get total by group
            $totals = $this->db->getHash("SELECT user_profiles.group_id,count(*) FROM user_profiles, armor_users WHERE user_profiles.uuid = armor_users.uuid AND $where_sql GROUP BY user_profiles.group_id");
            foreach ($user_groups as $group_id => $group_name) { 
                if (!isset($sets[$group_id])) { $sets[$group_id] = []; }
                $sets[$group_id][] = $totals[$group_id] ?? 0;
            }

            // Add label
            $this->addLabel($display_date);
        }

        // Add data sets
        foreach ($sets as $group_id => $points) { 
            $name = $user_groups[$group_id] ?? 'Unknown';
            $this->addDataset($points, $name);
        }

    }

}



