<?php
declare(strict_types = 1);

namespace App\Users\Opus\Graphs;

use Apex\Svc\Db;
use Apex\App\Base\Web\Render\Graph;
use Apex\App\Base\Web\Utils\GraphUtils;
use Apex\App\Interfaces\Opus\GraphInterface;

/**
 * Graph - OverallGroup
 */
class OverallGroup extends Graph implements GraphInterface
{

    /**
     * The type of graph.  Supported values are: bar, line, pie
     */
    public string $type = 'pie';

    /**
     * The labels of the X and Y axis
     */
    public string $label_yaxis = 'Amount';
    public string $label_xaxis = 'User Groups';

    #[Inject(GraphUtils::class)]
    private GraphUtils $graph_utils;

    #[Inject(Db::class)]
    private Db $db;


    /**
     * Get graph data
     */
    public function getData(array $attr = []):void
    {

        // initialize
        $graph_data = [];
        $user_groups = $this->db->getHash("SELECT id,name FROM user_groups ORDER BY id");

        // GO through user groups
        $totals = [];
        foreach ($user_groups as $group_id => $group_name) { 
            if (!$group_id > 0) { continue; }

            // Get total members
            $total = $this->db->getField("SELECT count(*) FROM user_profiles WHERE group_id = %i", $group_id);
            if ($total == '') { $total = 0; }

            // Add data
            $totals[] = $total;
            $this->addLabel($group_name);
        }

        // Add data set
        $this->addDataset($totals, 'User Groups');
    }

}

