<?php
declare(strict_types = 1);

namespace App\Users\Opus\Graphs;

use Apex\Svc\Db;
use Apex\App\Base\Web\Render\Graph;
use Apex\App\Base\Web\Utils\GraphUtils;
use Apex\App\Interfaces\Opus\GraphInterface;

/**
 * Graph - OverallStatus
 */
class OverallStatus extends Graph implements GraphInterface
{

    /**
     * The type of graph.  Supported values are: bar, line, pie
     */
    public string $type = 'pie';

    /**
     * The labels of the X and Y axis
     */
    public string $label_yaxis = 'Amount';
    public string $label_xaxis = 'Status';

    #[Inject(GraphUtils::class)]
    protected GraphUtils $graph_utils;

    #[Inject(Db::class)]
    protected Db $db;

    /**
     * Get graph data
     */
    public function getData(array $attr = []):void
    {

        // Set labels
        $this->setLabels(['Active', 'Inactive', 'Pending', 'Frozen']);

        // Get active
        if (!$active = $this->db->getField("SELECT count(*) FROM armor_users WHERE is_active = %b AND is_pending = %b AND is_deleted = %b", true, false, false)) {
            $active = 0;
        }

        // Get inactive
        if (!$inactive = $this->db->getField("SELECT count(*) FROM armor_users WHERE is_active = %b AND is_pending = %b AND is_deleted = %b", false, false, false)) {
            $inactive = 0;
        }

        // Get pending
        if (!$pending = $this->db->getField("SELECT count(*) FROM armor_users WHERE is_pending = %b AND is_deleted = %b", true, false)) {
            $pending = 0;
        }

        // Get frozen
        if (!$frozen = $this->db->getField("SELECT count(*) FROM armor_users WHERE is_frozen = %b AND is_deleted = %b", true, false)) {
            $frozen = 0;
        }

        // Add data set
        $this->addDataset([$active, $inactive, $pending, $frozen]);
    }

}

