<?php
declare(strict_types = 1);

namespace App\Users\Opus\Modals;

use Apex\Svc\{App, View};
use App\Users\User;
use App\Users\Exceptions\UserNotExistsException;
use Apex\App\Interfaces\Opus\ModalInterface;

/**
 * Modal - Manage
 */
class Manage implements ModalInterface
{

    #[Inject(App::class)]
    private App $app;

    #[Inject(View::class)]
    private View $view;

    /**
     * Display modal
     *
     * This function will be called when the modal is opened, and allows you to 
     * assign any necessary variables to the view to display within the modal.
     */
    public function show(View $view, App $app):void
    {

        // Initialize
        $uuid = $this->app->request('uuid');
        $is_admin = $this->app->getArea() == 'admin' ? 1 : 0;

        // Check for admin
        if ($this->app->getArea() != 'admin') {
            throw new \Exception("You do not have permission to perform this action.");
        }

        // Load user
        if (!$user = User::loadUuid($uuid)) {
            throw new UserNotExistsException("User does not exist with uuid, $uuid");
        }

        // Template variables
        $view->assign('uuid', $uuid);
        $view->assign('is_admin_modal', $is_admin);
        $view->assign('is_admin', 0);
        $view->assign('profile', $user->toDisplayArray());
    }

    /**
     * Submit
     * 
     * This function is executed upon the modal being submitted.
     */
    public function submit(App $app):void
    {

    }

}


