<?php
declare(strict_types = 1);

namespace App\Users\Opus\TabControls;

use Apex\Svc\{Db, View, App};
use Apex\Armor\Policy\ArmorPolicy;
use Apex\App\Interfaces\Opus\TabControlInterface;

/**
 * Tab Control - GeneralSettings
 */
class GeneralSettings implements TabControlInterface
{

    // Tab pages
    public array $tab_pages = [
        'General' => 'General',
        'Security' => 'Security'
    ];

    #[Inject(Db::class)]
    private Db $db;

    #[Inject(View::class)]
    private View $view;

    #[Inject(App::class)]
    private App $app;

    /**
     * Constructor
     *
     * All attributes within the <s:function> tag are passed to this method during instantiation, 
     * and here you can define various properties (ie. userid, type, et al) to be used in below methods.
     */
    public function __construct(
        private array $attr 
    ) { 

    }

    /**
     * Process the tab control
     *
     * This method will be called every time this tab control is displayed, allowing you to 
     * perform any necessary actions to populate the tab control, or process 
     * any submitted forms within it.
     */
    public function process():void
    {

        // Get user policy
        $policy = $this->getUserPolicy();

        // Update general settings
        if ($this->app->getAction() == 'general') {

            // Set vars
            $vars = [
                'redirect_after_login',
                'name_column',
                'name_required',
                'default_group'
            ];

            // Update config vars
            foreach ($vars as $var) {
                $this->app->setConfigVar('users.' . $var, $this->app->post($var));
            }

            // Set policy properties
            $policy->setUsernameColumn($this->app->post('username_column'));
            $policy->setRequireEmail($this->app->post('require_email'));
            $policy->setRequirePhone($this->app->post('require_phone'));
            $policy->setVerifyEmail($this->app->post('verify_email'));
            $policy->setVerifyPhone($this->app->post('verify_phone'));
        $policy->setMinPasswordStrength((int) $this->app->post('min_password_strength'));
            $policy->setCreateAsPending((bool) $this->app->post('mark_as_pending'));

            // Update policy
            $this->db->update('armor_policies', [
            'policy' => base64_encode(serialize($policy))
            ], "name = 'users'");

            // Set template vars
            $this->view->assign('policy', $policy->toArray());
            $this->view->addCallout('Successfully updated general user settings.');
        }

    }

    /**
     * Get user policy
     */
    public function getUserPolicy():ArmorPolicy
    {

        // Get row
        if (!$policy = $this->db->getField("SELECT policy FROM armor_policies WHERE name = 'user'")) { 
            throw new \Exception("No security policy exists with the name 'user'");
        }

        // Get policy
        $obj = unserialize(base64_decode($policy));
        $this->view->assign('policy', $obj->toArray());

        // Return
        return $obj;
    }

}



