<?php
declare(strict_types = 1);

namespace App\Users\Opus\TabControls;

use Apex\Svc\{View, App};
use App\Users\User;
use App\Users\Models\Note;
use App\Users\Exceptions\UsersNotExistsException;
use Apex\App\Interfaces\Opus\TabControlInterface;

/**
 * Tab Control - Manage
 */
class Manage implements TabControlInterface
{

    #[Inject(View::class)]
    private View $view;

    #[Inject(App::class)]
    private App $app;

    // Tab pages
    public array $tab_pages = [
        'Profile' => 'Profile',
        'Additional' => 'Additional',
        'Log' => 'Log'
    ];

    /**
     * Constructor
     *
     * All attributes within the <s:function> tag are passed to this method during instantiation, 
     * and here you can define various properties (ie. userid, type, et al) to be used in below methods.
     */
    public function __construct(
        private array $attr 
    ) { 

    }

    /**
     * Process the tab control
     *
     * This method will be called every time this tab control is displayed, allowing you to 
     * perform any necessary actions to populate the tab control, or process 
     * any submitted forms within it.
     */
    public function process():void
    {

        // Load user
        $uuid = $this->attr['userid'] ?? '';
        if ($uuid == '') { 
            return;
        } elseif (!$user = User::loadUuid($uuid)) { 
            throw new UsersNotExistsException("No user exists with the uuid, $uuid");
        }

        // Add note
        if ($this->app->getAction() == 'add_note') { 
            $user->addNote($this->app->post('note'));
            $this->view->addCallout("Successfully added note to user's account.");
        }

        // Load profile
        $profile = $user->toDisplayArray();
        $this->view->assign('profile', $profile);
    }

}



