<?php
declare(strict_types = 1);

namespace App\Users\Tasks;

use Apex\Svc\{SmsClient, App, Emailer, Container};
use Apex\App\Sys\TaskModel;
use App\Users\Helpers\FilterCriteria;
use Apex\Mercury\Email\EmailMessage;
use redis;

/**
 * Broadcast e-mail to all users
 */
class BroadcastSMS
{

    #[Inject(FilterCriteria::class)]
    private FilterCriteria $filter;

    #[Inject(SmsClient::class)]
    private SmsClient $sms;

    #[Inject(App::class)]
    private App $app;

    #[Inject(Container::class)]
    private Container $cntr;

    #[Inject(Emailer::class)]
    private Emailer $emailer;

    #[Inject(redis::class)]
    private redis $redis;

    /**
     * Process
     */
    public function process(TaskModel $task, array $data):void
    {

        // Initialize
        $start = time();

        // Get offset from redis
        $redis_key = 'tmp:task:' . $task->id;
        if (!$offset = $this->redis->get($redis_key)) {
            $this->redis->set($redis_key, 0);
            $offset = 0;
        }

        // Get users to e-mail
        $users = $this->filter->filter($data, $offset);

        // Go through users
        foreach ($users as $user) {

        // Skip, if needed
        if ($user->getPhone() == '') {
            continue;
        }

            // Merge message vars
            $message = $data['message'];
            foreach ($user->toDisplayArray() as $key => $value) {
                if (!is_scalar($value)) {
                    continue;
                }
                $message = str_replace("~$key~", (string) $value, $message);
            }

            // Send SMS message
            $this->sms->send($user->getPhone(), $message);
            $this->redis->incrby($redis_key, 1);
        }

        // Get total sent
        $total = $this->redis->get($redis_key);
        $this->redis->del($redis_key);

        // Send summary
        $secs = (time() - $start);
        $this->sendSummary($data, (int) $total, $secs);
    }

    /**
     * Send summary
     */
    private function sendSummary(array $data, int $total, int $secs):void
    {

        // Set message
        $site_name = $this->app->config('core.site_name') . ' (' . $this->app->config('core.domain_name') . ')';
        $message = "\nThis is confirmation that the broadcast SMS you sent to all users of $site_name has been completed.  A total of $total SMS messages were delivered in $secs seconds.\r\n\r\n-- END --\r\n";

        // Create message
        $email = $this->cntr->make(EmailMessage::class, [
            'to_email' => $data['admin_email'],
            'to_name' => $data['admin_name'],
            'from_email' => $data['admin_email'],
            'from_name' => $data['admin_name'],
            'subject' => 'Broadcast SMS Complete - ' . $site_name,
            'text_message' => $message
        ]);

        // Send e-mail
        $this->emailer->send($email);
    }

}


