<?php
declare(strict_types = 1);

namespace App\Webapp;

use Apex\Svc\{App, Db, Container};
use App\Webapp\Models\DashboardProfile;
use App\Webapp\Exceptions\WebappDashboardException;

/**
 * Dashboard
 */
class Dashboard
{

    #[Inject(App::class)]
    private App $app;

    #[Inject(Db::class)]
    private Db $db;

    #[Inject(Container::class)]
    private Container $cntr;

    /**
     * GEt profile
     */
    public function getProfile():DashboardProfile
    {

        // Get profile id
        $profile_id = $this->getProfileId();

        // Start profile
        $profile = $this->cntr->make(DashboardProfile::class, [
            'profile_id' => $profile_id
        ]);

        // Go through classes
        $classes = $this->db->getColumn("SELECT class_name FROM dashboard_profiles_items WHERE profile_id = %i ORDER BY id", $profile_id);
        foreach ($classes as $class_name) {

            // Load class
            $obj = $this->cntr->make($class_name);
            $type = $obj->type ?? '';

            // Check type
            if ($type == 'top') {
                $profile->addTopItem($obj);
            } elseif ($type == 'right') {
                $profile->addRightItem($obj);
            } elseif ($type == 'tab') {
                $profile->addTab($obj);
            }
        }

        // Return
        return $profile;
    }

    /**
     * Get profile id
     */
    private function getProfileId():int
    {

        // Get profile id
        if ($profile_id = $this->db->getField("SELECT id FROM dashboard_profiles WHERE area = %s AND uuid = %s AND is_default = %b", $this->app->getArea(), $this->app->getUuid(), false)) {
            return (int) $Profile_id;
        }

        // Get default profile
        if (!$profile_id = $this->db->getField("SELECT id FROM dashboard_profiles WHERE area = %s AND is_default = %b", $this->app->getArea(), true)) {
            throw new WebappDashboardException("No default dashboard profile exists for the area, " . $this->app->getArea());
        }

        // Return
        return (int) $profile_id;
    }

}



