<?php
declare(strict_types = 1);

namespace App\Webapp\Opus\Ajax;

use Apex\Svc\{App, Db};
use Apex\App\Base\Web\{Ajax, Components};
use Apex\App\Exceptions\ApexComponentNotExistsException;
use Apex\App\Interfaces\Opus\AjaxInterface;

/**
 * Ajax - DeleteCheckedRows
 */
class DeleteCheckedRows extends Ajax implements AjaxInterface
{

    #[Inject(App::class)]
    protected App $app;

    #[Inject(Db::class)]
    protected Db $db;

    #[Inject(Components::class)]
    protected Components $components;

    /**
     * Process AJAX function
     */
    public function process():void
    {

        // Load table
        $attr = $this->app->getAllPost();
        if (!$table = $this->components->load('DataTable', $this->app->post('table'), ['attr' => $attr])) {
            throw new ApexComponentNotExistsException("No data table exists with the alias, " . $this->app->post('table'));
        }

        // Get IDs
        $form_name = preg_replace("/\[\]$/", "", $table->form_name);
        $ids = $this->app->post($form_name);

        // Delete
        foreach ($ids as $id) { 
            if ($id == '') {
                continue;
            }
            $this->db->query("DELETE FROM $table->delete_dbtable WHERE $table->delete_dbcolumn = %s", $id);
        }

        // AJAX
        if (isset($attr['id'])) {
            $this->removeCheckedRows($attr['id']);
        }
    }

}


