<?php
declare(strict_types = 1);

namespace App\Webapp\Opus\Ajax;

use Apex\Svc\App;
use Apex\App\Base\Web\{Ajax, Components};
use Apex\App\Interfaces\Opus\AjaxInterface;
use Apex\App\Exceptions\ApexComponentNotExistsException;

/**
 * Ajax - SearchAutoComplete
 */
class SearchAutoComplete extends Ajax
{

    #[Inject(App::class)]
    protected App $app;

    #[Inject(Components::class)]
    protected Components $components;

    /**
     * Process AJAX function
     */
    public function process():array
    {

        // Load autosuggest
        if (!$auto_complete = $this->components->load('AutoComplete', $this->app->get('autocomplete'))) { 
            throw new ApexComponentNotExistsException("No auto-complete list exists at this location.");
        }

        // Get options
        $term = $this->app->get('term', '');
        $options = $auto_complete->search($term);

        // Format options
        $results = [];
        foreach ($options as $id => $label) {
            $results[] = [
                'label' => $label,
                'data' => $id
            ];
        }

        // return
        return $results;
    }

}


