<?php
declare(strict_types = 1);

namespace App\Webapp\Opus\Ajax;

use Apex\Svc\{App, Container};
use Apex\App\Base\Web\Components;
use Apex\App\Base\Web\Utils\DataTableDetails;
use Apex\App\Base\Web\Ajax;
use Apex\App\Exceptions\ApexComponentNotExistsException;
use Apex\App\Interfaces\Opus\AjaxInterface;

/**
 * Ajax - SearchTable
 */
class SearchTable extends Ajax implements AjaxInterface
{

    #[Inject(App::class)]
    protected App $app;

    #[Inject(Container::class)]
    protected Container $cntr;

    #[Inject(Components::class)]
    protected Components $components;

    /**
     * Process AJAX function
     */
    public function process():void
    {

        // Set variables
        $id = $this->app->post('id') ?? '';
        $search_text = $this->app->post('search_' . $id) ?? '';
        if ($search_text == '') { 
            $this->alert(tr('You did not specify any text to search for.'));
            return;
        }

        // Load table
        $attr = $this->app->getAllPost();
        if (!$table = $this->components->load('DataTable', $this->app->post('table'), ['attr' => $attr])) {
            throw new ApexComponentNotExistsException("No data table exists with the alias, " . $this->app->post('table'));
        }

        // Get table details
        $details = $this->cntr->make(DataTableDetails::class, [
            'divid' => $this->app->post('id'),
            'table' => $table
        ]);

        // Clear table rows
        $this->clearTable($this->app->post('id'));

        // Add new rows
        $this->addDataRows($id, $this->app->post('table'), $details->rows, $this->app->getAllPost());

        // Set pagination
        $this->setPagination($this->app->post('id'), $details);
    }

}


