<?php
declare(strict_types = 1);

namespace App\Webapp\Opus\DashboardItems;

use Apex\Svc\Db;
use Apex\App\Interfaces\Opus\DashboardItemInterface;

/**
 * Dashboard item - AdminsOnline
 */
class AdminsOnline implements DashboardItemInterface
{

    /**
     * The type of dashboard item.
     * Can be either:  top, right, tab
     */
    public string $type = 'top';

    /**
     * The area this dashboard item is available.  
     * Generally will only ever be either 'admin' or 'members'.
     */
    public string $area = 'admin';

    /**
     * Whether or not to activate this dashboard item upon initial installation
     */
    public bool $is_default = false;

    /**
     * The title of the dashboard item.
     */
    public string $title = 'Admins Online';

    /**
     * The div id and panel class name of the dashboard item.
     * Only applicable for items with $type of 'top'.
     */
    public string $divid = 'members-online';
    public string $panel_class = 'panel bg-teal-400';

    #[Inject(Db::class)]
    private Db $db;


    /**
     * Render the dashboard item.
     *
     * @return The HTML contents of the dashboard item.
     */
    public function render():string
    {

        if (!$total = $this->db->getField("SELECT count(*) FROM admin")) {
            $total = 0;
        }

        // Return
        return (string) $total;
    }

}


