<?php
declare(strict_types = 1);

namespace App\Webapp\Opus\DataTables;

use Apex\Svc\{App, Db};
use Apex\App\Base\Implementors;
use Apex\App\Interfaces\EmailNotificationControllerInterface;
use Apex\App\Interfaces\Opus\DataTableInterface;

/**
 * Data Table - EmailNotifications
 */
class EmailNotifications implements DataTableInterface
{

    // Columns
    public array $columns = [
        'controller' => 'Controller',
        'recipient' => 'Recipient',
            'subject' => 'Subject',
        'manage' => 'Manage'
    ];
    public array $sortable = ['controller', 'subject', 'recipient'];

    // Other variables
    public int $rows_per_page = 25;
    public bool $has_search = true;

    // Form field (left-most column)
    public string $form_field = 'checkbox';
    public string $form_name = 'email_notification_id';
    public string $form_value = 'id'; 

    // Delete button
    public string $delete_button = 'Delete Checked Email Notifications';
    public string $delete_dbtable = 'internal_email_notifications';
    public string $delete_dbcolumn = 'id';


    /**
     * Constructor
     *
     * All attributes within the <s:function> tag are passed to this method during instantiation, 
     * and here you can define various properties (ie. userid, type, et al) to be used in below methods.
     */
    public function __construct(
        private array $attr, 
        private App $app, 
        private Db $db,
        private Implementors $implementors
    ) { 
        $this->controllers = $implementors->getPropertyValues(EmailNotificationControllerInterface::class, 'title');
    }

    /**
     * Get total rows in data set - used for pagination.
     */
    public function getTotal(string $search_term = ''):int 
    {

        // Get total
        if ($search_term != '') {
            $total = $this->db->getField("SELECT count(*) FROM internal_email_notifications WHERE subject LIKE %ls OR contents LIKE %ls", $search_term, $search_term);
        } else {
            $total = $this->db->getField("SELECT count(*) FROM internal_email_notifications");
        }

        // Return
        return (int) $total;
    }

    /**
     * Get rows to display on current page.
     *
     * Should return an array with each element being an associative array representing one table row.
     */ 
    public function getRows(int $start = 0, string $search_term = '', string $order_by = 'subject asc'):array 
    {

        // Get rows
        if ($search_term != '') {
            $rows = $this->db->query("SELECT * FROM internal_email_notifications WHERE subject LIKE %ls OR contents LIKE %ls ORDER BY $order_by LIMIT $start,$this->rows_per_page", $search_term, $search_term);
        } else {
            $rows = $this->db->query("SELECT * FROM internal_email_notifications ORDER BY $order_by LIMIT $start,$this->rows_per_page");
        }

        // Go through rows
        $results = [];
        foreach ($rows as $row) { 
            $results[] = $this->formatRow($row);
        }

        // Return
        return $results;
    }

    /**
     * Format individual row for display to browser.
     */
    public function formatRow(array $row):array
    {

        // Format
        $row['controller'] = $this->controllers[$row['controller']] ?? 'Unknown';
        $row['manage'] = "<center><s:button href=\"/admin/settings/notifications_edit?notification_id=$row[id]\" label=\"Manage\"></center>";

        // Return
        return $row;
    }

}

