<?php
declare(strict_types = 1);

namespace App\Webapp\Opus\DataTables;

use Apex\Svc\{App, Db};
use Apex\App\Interfaces\Opus\DataTableInterface;

/**
 * Data Table - SecurityPolicies
 */
class SecurityPolicies implements DataTableInterface
{

    // Columns
    public array $columns = [
        'name' => 'Name',
        'manage' => 'Manage'
    ];
    public array $sortable = ['id'];

    // Other variables
    public int $rows_per_page = 25;
    public bool $has_search = false;

    // Form field (left-most column)
    public string $form_field = 'checkbox';
    public string $form_name = 'policy_id';
    public string $form_value = 'id'; 

    // Delete button
    public string $delete_button = 'Delete Checked Security Policies';
    public string $delete_dbtable = 'armor_policies';
    public string $delete_dbcolumn = 'id';

    /**
     * Constructor
     *
     * All attributes within the <s:function> tag are passed to this method during instantiation, 
     * and here you can define various properties (ie. userid, type, et al) to be used in below methods.
     */
    public function __construct(
        private array $attr, 
        private App $app, 
        private Db $db
    ) { 

    }

    /**
     * Get total rows in data set - used for pagination.
     */
    public function getTotal(string $search_term = ''):int 
    {
        $total = $this->db->getField("SELECT count(*) FROM armor_policies");
        return (int) $total;
    }

    /**
     * Get rows to display on current page.
     *
     * Should return an array with each element being an associative array representing one table row.
     */ 
    public function getRows(int $start = 0, string $search_term = '', string $order_by = 'name asc'):array 
    {

        // Get rows
        $rows = $this->db->query("SELECT * FROM armor_policies ORDER BY $order_by LIMIT $start,$this->rows_per_page");

        // Go through rows
        $results = [];
        foreach ($rows as $row) { 
            $results[] = $this->formatRow($row);
        }

        // Return
        return $results;
    }

    /**
     * Format individual row for display to browser.
     */
    public function formatRow(array $row):array
    {

        // Format
        $row['manage'] = "<center><s:button href=\"/admin/settings/security_edit?policy=$row[name]\" label=\"Manage\"></center>";

        // Return
        return $row;
    }

}

