<?php
declare(strict_types = 1);

namespace App\Webapp\Opus\Forms;

use Apex\Svc\{App, Db};
use Apex\App\Base\Web\Utils\FormBuilder;
use App\Webapp\AdminProfiles;
use Apex\App\Interfaces\Opus\FormInterface;

/**
 * Form - SendEmail
 */
class BroadcastEmailForm implements FormInterface
{

    /**
     * Whether or not to pre-populate form fields with POSTed data.
     */
    public bool $allow_post_values = true;

    #[Inject(FormBuilder::class)]
    private FormBuilder $builder;

    #[Inject(Db::class)]
    private Db $db;

    #[Inject(App::class)]
    private App $app;

    #[Inject(AdminProfiles::class)]
    private AdminProfiles $admin_profiles;

    /**
     * Get form fields.
     */
    public function getFields(array $attr = []):array
    {

        // Initialize
        $builder = $this->builder;

        // Admin options
        $admin_id = $this->app->post('sender', '');
        $admin_options = $this->admin_profiles->createSelectOptions($admin_id);

        // Set form fields
        $form_fields = [
            'date' => $builder->date()->required()->label('Send Date'),
            'time' => $builder->time()->required()->label('Send Time'),
            'sender' => $builder->select()->required()->options($admin_options),
            'reply_to' => $builder->textbox(),
            'sep_message' => $builder->seperator('Message Contents'),
            'subject' => $builder->textbox()->required(),
            'attachment' => $builder->textbox()->type('file'),
            'text_message' => $builder->textarea(),
            'html_message' => $builder->textarea(),
            'submit' => $builder->submit()->value('send')->label('Broadcast E-Mail Message')
        ];

        // Return
        return $form_fields;
    }

    /**
     * Get record
     */
    public function getRecord(string $record_id):array
    {

        // Get row
        if (!$row = $this->db->getIdRow('', $record_id)) { 
            $row = [];
        }

        // Return
        return $row;
    }

    /**
     * Validate
     */
    public function validate(array $attr = []):bool
    {

        // Return
        return true;
    }

}

