<?php
declare(strict_types = 1);

namespace App\Webapp\Opus\Forms;

use Apex\Svc\Db;
use Apex\App\Base\Web\Utils\FormBuilder;
use Apex\App\Interfaces\Opus\FormInterface;

/**
 * Form - SecurityPolicy
 */
class SecurityPolicy implements FormInterface
{

    /**
     * Whether or not to pre-populate form fields with POSTed data.
     */
    public bool $allow_post_values = false;

    #[Inject(FormBuilder::class)]
    private FormBuilder $builder;

    #[Inject(Db::class)]
    private Db $db;

    /**
     * Get form fields.
     */
    public function getFields(array $attr = []):array
    {

        // Initialize
        $builder = $this->builder;

        // Set form fields
        $fields = [
            'name' => $builder->textbox()->required()->dataType('alphanum')->label('Policy Name'),
            'sep_username' => $builder->seperator('Username'),
            'username_column' => $builder->select()->required()->dataSource('hash.webapp.username_column'),
            'min_username_length' => $builder->textbox()->required()->width('70px')->dataType('integer')->value('0'),
            'create_as_pending' => $builder->boolean()->value(false),
            'sep_password' => $builder->seperator('Password'),
            'require_password' => $builder->select()->required()->dataSource('hash.webapp.require_password')->value('require'),
            'min_password_strength' => $builder->select()->required()->dataSource('hash.webapp.password_strength')->value('medium'),
            'sep_email' => $builder->seperator('E-Mail Address'),
            'require_email' => $builder->select()->required()->dataSource('hash.webapp.require_email')->value('require'),
            'verify_email' => $builder->select()->required()->dataSource('hash.webapp.verify_email')->value('none'),
            'expire_verify_email_secs' => $builder->textbox()->required()->width('70px')->dataType('integer')->value('600')->label('Second to Expire Verification E-Mail'),
            'sep_phone' => $builder->seperator('Phone Number'),
            'require_phone' => $builder->select()->required()->dataSource('hash.webapp.require_email')->value('none'),
            'verify_phone' => $builder->select()->required()->dataSource('hash.webapp.verify_phone')->value('none'),
            'expire_verify_phone_secs' => $builder->textbox()->required()->width('70px')->dataType('integer')->value('600')->label('Second to Expire Verification SMS'),
            'sep_2fa' => $builder->seperator('Two Factor Authentication'),
            'two_factor_type' => $builder->select()->required()->dataSource('hash.webapp.two_factor_type')->value('none')->label('Global Type'),
            'two_factor_frequency' => $builder->select()->required()->dataSource('hash.webapp.two_factor_frequency')->value('none')->label('Global Frequency'),
            'default_two_factor_type' => $builder->select()->required()->dataSource('hash.webapp.two_factor_type')->value('none')->label('Upon Register Type'),
            'default_two_factor_frequency' => $builder->select()->required()->dataSource('hash.webapp.two_factor_frequency')->value('none')->label('Upon Register Frequency'),
            'sep_session' => $builder->seperator('Login Session'),
            'expire_session_inactivity_secs' => $builder->textbox()->value('1800')->required()->dataType('integer')->width('70px')->label('Seconds of Inactivity to Expire'),
            'expire_redis_session_secs' => $builder->textbox()->value('1800')->required()->dataType('integer')->width('70px')->label('Seconds of Inactivity to Expire (redis)'),
            'lock_redis_expiration' => $builder->boolean()->value(false),
            'enable_ipcheck' => $builder->boolean()->value(false)->label('Enable IP Restrictions'),
            'sep_remember' => $builder->seperator('Remember Me'),
            'remember_me_days' => $builder->textbox()->required()->value('30')->dataType('integer')->width('70px')->label('Days to Expire Remember Me'),
            'remember_device_days' => $builder->textbox()->required()->value('90')->dataType('integer')->width('70px')->label('Days to Remember Devices'),
            'submit' => $builder->createOrUpdateButton('Security Policy', $attr)
        ];

        // Return
        return $fields;
    }

    /**
     * Get record
     */
    public function getRecord(string $record_id):array
    {

        // Get row
        if (!$policy = $this->db->getField("SELECT policy FROM armor_policies WHERE name = %s", $record_id)) { 
            return [];
        }

        // Get policy
        $obj = unserialize(base64_decode($policy));
        $row = $obj->toArray();
        $row['name'] = $record_id;

        // Return
        return $row;
    }

    /**
     * Validate
     */
    public function validate(array $attr = []):bool
    {

        // Return
        return true;
    }

}

