<?php
declare(strict_types = 1);

namespace Views\admin\cms;

use Apex\Svc\{View, App};
use Apex\App\Sys\Utils\SiteConfig;

/**
 * Render the template.
 */
class layouts
{

    /**
     * Render
     */
    public function render(View $view, App $app, SiteConfig $site_config):void
    {

        // Get default theme
        $config = $app->getRoutesConfig('site.yml');
        $layout_dir = SITE_PATH . '/views/themes/' . $config['themes']['default'] . '/layouts';

        // Update titles
        if ($app->getAction() == 'update_title') {

            // Go through titles
            foreach ($config['page_vars']['title'] as $uri => $title) {
                $config['page_vars']['title'][$uri] = $app->post('title_' . $uri);
            }

            // Save file
            file_put_contents(SITE_PATH . '/boot/site.yml', $site_config->generateText($config));
            $view->addCallout('Successfully updated page titles as necessary.');

        // Update layout
        } elseif ($app->getAction() == 'update_layout') {

            // Go through layours
            foreach ($config['page_vars']['layouts'] as $uri => $layout) {
                $config['page_vars']['layouts'][$uri] = $app->post('loayout_' . $uri);
            }

            // Save file
            file_put_contents(SITE_PATH . '/boot/site.yml', $site_config->generateText($config));
            $view->addCallout('Successfully updated page layouts as necessary.');

        // Add page titles
        } elseif ($app->getAction() == 'add_titles') {

            for ($x=1; $x <= 10; $x++) {
                $uri = trim($app->post('title_new_uri' . $x), '/');
                if ($uri == '') {
                    break;
                }
                $config['page_vars']['title'][$uri] = $app->post('title_new_title' . $x);
            }

            // Save file
            file_put_contents(SITE_PATH . '/boot/site.yml', $site_config->generateText($config));
            $view->addCallout('Successfully added all necessary page titles.');

        // Add layouts
        } elseif ($app->getAction() == 'add_layout') {

            for ($x=1; $x <= 10; $x++) {
                $uri = trim($app->post('layout_new_uri' . $x), '/');
                if ($uri == '') {
                    break;
                }
                $config['page_vars']['layouts'][$uri] = $app->post('layout_new_layout' . $x);
            }

            // Save file
            file_put_contents(SITE_PATH . '/boot/site.yml', $site_config->generateText($config));
            $view->addCallout('Successfully added all necessary page layouts.');
        }

        // Check if writeable
        $not_writeable = is_writeable(SITE_PATH . '/boot/site.yml') ? 0 : 1;
        $view->assign('not_writeable', $not_writeable);

        // Create layout options
        $options = '';
        if (is_dir($layout_dir)) {
            $files = scandir($layout_dir);
            foreach ($files as $file) {
                if (!preg_match("/^(.+)\.html$/", $file, $m)) {
                    continue;
                }

                $chk = $m[1] == 'default' ? 'selected="selected"' : '';
                $options .= "<option value=\"$m[1]\" $chk>$m[1]</option>";
            }
        }

        // Add foreach blocks
        for ($x=1; $x <= 10; $x++) {
            $view->addBlock('title_num', ['num' => $x]);
            $view->addBlock('layout_num', [
                'num' => $x,
                'options' => $options
            ]);
        }

    }

}


