<?php
declare(strict_types = 1);

namespace Views\admin\cms;

use Apex\Svc\{View, App, Db, Container};
use Apex\App\Pkg\Config\Menus as MenusConfig;

/**
 * Render the template.
 */
class menus
{

    /**
     * Render
     */
    public function render(View $view, App $app, Db $db, Container $cntr):void
    {

        // Update menus
        if (preg_match("/^update_(.+)$/", $app->getAction(), $m)) {
            $area = $m[1];

            // Delete neded menus
            $deletes = $app->post('delete', []);
            foreach ($deletes as $menu_id) { 
                $db->query("DELETE FROM cms_menus WHERE id = %i", $menu_id);
            }

            // Update 'is_active'
            $is_active = $app->post('is_active', []);
            $db->query("UPDATE cms_menus SET is_active = %b WHERE area = %s", false, $area);
            foreach ($is_active as $menu_id) { 
                $db->query("UPDATE cms_menus SET is_active = %b WHERE id = %s", true, $menu_id);
            }

            // Update ordering as needed
            $rows = $db->query("SELECT * FROM cms_menus WHERE area = %s", $area);
            foreach ($rows as $row) { 
                $order_num = $app->post('order_' . $row['id']);
                $db->query("UPDATE cms_menus SET order_num = %i WHERE id = %i", $order_num, $row['id']);
            }

            // Update redis
            $config = $cntr->make(MenusConfig::class, ['pkg_alias' => 'core']);
            $config->syncRedis();

            // Call out
            $view->addCallout("Successfully updated $area menus as needed");

        // Add new menu
        } elseif ($app->getAction() == 'create') {

            // Set variables
            $require_login = $app->post('require_login', 0);
            $require_nologin = $app->post('require_nologin', 0);

            // Add to DB
            $db->insert('cms_menus', [
                'package' => '', 
                'area' => $app->post('area'), 
                'is_system' => false, 
                'require_login' => $require_login == 1 ? true : false,
                'require_nologin' => $require_nologin == 1 ? true : false,
                'order_num' => $app->post('order_num'), 
                'type' => $app->post('type'), 
                'icon' => $app->post('icon'), 
                'parent' => $app->post('parent'), 
                'alias' => $app->post('alias'), 
                'name' => $app->post('name'), 
                'url' => $app->post('url')
            ]);

            // Update redis
            $config = $cntr->make(MenusConfig::class, ['pkg_alias' => 'core']);
            $config->syncRedis();

            // Add callout
            $view->addCallout(tr("Successfully added new menu, %s", $app->post('name')));

        // Update menu
        } elseif ($app->getAction() == 'update') { 

            // Set variables
            $require_login = $app->post('require_login', 0);
            $require_nologin = $app->post('require_nologin', 0);

            // Update database
            $db->update('cms_menus', [
                'area' => $app->post('area'), 
                'require_login' => $require_login == 1 ? true : false,
                'require_nologin' => $require_nologin == 1 ? true : false,
                'order_num' => $app->post('order_num'), 
                'type' => $app->post('type'), 
                'icon' => $app->post('icon'), 
                'parent' => $app->post('parent'), 
                'alias' => $app->post('alias'), 
                'name' => $app->post('name'), 
                'url' => $app->post('url')],
            "id = %i", $app->post('menu_id'));

            // Update redis
            $config = $cntr->make(MenusConfig::class, ['pkg_alias' => 'core']);
            $config->syncRedis();

            // User message
            $view->addCallout(tr("Successfully updated menu, %s", $app->post('name')));
        }

    }

}


