<?php
declare(strict_types = 1);

namespace Views\admin\financial;

use Apex\Svc\{View, App, Container};
use App\Transaction\Helpers\AdapterOptions;
use App\Transaction\Handlers\TxHandler;
use App\Transaction\Models\{Currency, Tx};
use App\Transaction\Enums\TxStatus;
use App\Transaction\Exceptions\TxValidationException;

/**
 * Render the template.  All methods below are optional, may be 
 * removed as desired, and all methods support method based dependency injection.
 */
class add
{

    /**
     * Render.  This method will be called with every view 
 * regardless of the HTTP method.
     */
    public function render(View $view, App $app, AdapterOptions $adapter_options):void
    {

        // Create adapter options
        $options = $adapter_options->create();
        $status_options = $adapter_options->createStatusOptions();

        // Check number of currencies
        $count = Currency::count();
        $show_currency = $count > 1 ? 1 : 0;

        // Template variables
        $view->assign('adapter_options', $options);
        $view->assign('status_options', $status_options);
        $view->assign('show_currency', $show_currency);
    }

    /**
     * Post.  Will only be called when the HTTP method is POST.
     */
    public function post(View $view, App $app, Container $cntr, TxHandler $handler):void
    {

        // Start tx vars
        $vars = [
            'uuid' => $app->post('user_id'),
            'adapter' => $app->post('adapter'),
            'amount' => (float) $app->post('amount'),
            'description' => $app->post('description')
        ];

        // Add currency
        if ($app->hasPost('currency')) {
            $vars['currency'] = $app->post('currency');
        }

        // Add status
        if ($app->post('status') != '') {
            $vars['status'] = TxStatus::from($app->post('status'));
        }

        // Instantiate tx
        $tx = $cntr->make(Tx::class, $vars);

        // Create tx
        try {
            $tx = $handler->create($tx, $app->post('note'));
            $view->addCallout('Successfully added transaction to necessary user.');
        } catch (TxValidationException $e) {
            $view->addCallout($e->getMessage(), 'error');
        }

    }

}

