<?php
declare(strict_types = 1);

namespace Views\admin\settings;

use Apex\Svc\{View, App};
use App\Webapp\AdminProfiles;

/**
 * Render the template.
 */
class admin
{

    /**
     * POST
     */
    public function post(View $view, App $app, AdminProfiles $admin_profiles):void
    {

        // Create admin
        if ($app->getAction() == 'create') {

            if (null !== ($user = $admin_profiles->create(false))) {
                $view->addCallout('Successfully created new administrator, ' . $user->getUsername());
            }

        // Update administrator
        } elseif ($app->getAction() == 'update') {

            if (!$user = $admin_profiles->loadUuid($app->post('admin_id'))) {
                $view->addCallout('Unable to load administrator with uuid, ' . $app->post('admin_id'), 'error');
                return;
            }

            // Update
            $admin_profiles->update($user);
            $view->addCallout('Successfully updated the administrator, ' . $user->getUsername());

        // Delete
        } elseif ($app->getAction() == 'delete') {

            $admins = $app->post('admin_id', []);
            foreach ($admins as $uuid) {
                $admin_profiles->delete($uuid);
            }
            $view->addCallout('Successfully deleted all checked administrators.');

        // Change password
        } elseif ($app->getAction() == 'change_password') {

            // Checks
            if ($app->post('new_password') == '' || $app->post('new_password') != $app->post('new_password2')) {
                $view->addCallout('The two passwords do not match.', 'error');
                return;
            } elseif ($app->post('old_password') == '' && $app->post('master_password') == '') {
                $view->addCallout('Either the old or master password is required in order to change a password.', 'error');
                return;
            } elseif (!$user = $admin_profiles->loadUuid($app->post('admin_id'))) {
                $view->addCallout('Unable to load administrator with uuid, ' . $app->post('admin_id'), 'error');
                return;
            }

            // Update password
            if ($app->post('old_password') != '') {
                $user->updatePassword($app->post('new_password'), $app->post('old_password'));
            } elseif ($app->post('master_password') != '') {
                $user->updatePasswordWithMaster($app->post('new_password'), $app->post('master_password'));
            }

            // Callout
            $view->addCallout('Successfully updated the administrator password, ' . $user->getUsername());

        // Upate allowed menus
        } elseif ($app->getAction() == 'update_menus') {
            $acl = $app->post('acl', []);
            $admin_profiles->updateMenuAcl($app->post('admin_id'), $acl);
            $view->addCallout("Successfully updated allowed menus of administrator.");
        }

    }


}


