<?php
declare(strict_types = 1);

namespace Views\admin\users;

use Apex\Svc\{View, App};
use App\Users\{User, UserProfiles};

/**
 * Render the template.
 */
class manage
{

    /**
     * Render
     */
    public function render(View $view, App $app, UserProfiles $profiles):void
    {

        // Check if we're managing a user
        $userid = $app->post('user_id', '');
        if ($userid == '') { 
            $userid = $app->request('manage_id', '');
        }

        // Check for disabled Javascript
        if ($app->config('core.enable_javascript') != 1 && $app->hasPost('user')) {
            if ($user = User::loadUsername($app->post('user'))) {
                $userid = $user->getUuid();
            } else {
                $view->addCallout("No user exists with the username, " . $app->post('user'), 'error');
            }
        }


        // Get show_user or not
        $show_user = $userid == '' ? 0 : 1;

        // Update profile
        if ($userid != '' && $app->getAction() == 'update_profile') { 

            // Update user
            $user = User::loadUuid($userid);
            $profiles->update($user);

            // User message
            $view->addCallout("Successfully updated user's profile.");

        // Change password
        } elseif ($app->getAction() == 'change_password') { 

            // Load user
            $user = app::make(user::class, ['id' => $userid]);
            if ($user->change_password(app::_post('password'), app::_post('new_password')) === true) { 
                view::add_callout("Successfully updated the user password");
            }
        }

        // Template variables
        $view->assign('show_user', $show_user);
        $view->assign('user_id', $userid);

    }

    /**
     * Post
     */
    public function post(View $view, App $app, UserProfiles $profiles):void
    {

        // Load user
        if (!$user = User::loadUuid($app->post('manage_id'))) {
            return;
        }

        // Update profile
        if ($app->getAction() == 'update') { 
            $profiles->updateAsAdmin($user, []);
            $view->addCallout("Successfully updated user's profile.");

        // Change password
        } elseif ($app->getAction() == 'changePassword') {
            $this->changePassword($view, $app, $user, $validator);
        }

    }

    /**
     * Change Password
     */
    private function changePassword(View $view, App $app, User $user):void
    {

        // Validate
        if ($app->post('password') != $app->post('password2')) {
            $view->addCallout('Password do not match');
            $view->setTemplateFile('admin/users/change_password');
            return;
        }

        // Update password
        if (!$user->updatePasswordWithMaster($app->post('password'), $app->post('master_password'))) {
            $view->addCallout("Unable to update password as the master password is incorrect.", 'error');
            return;
        }

        // Callout
        $view->addCallout("Successfully updated user's password.");
    }

}


