<?php
declare(strict_types = 1);

namespace Views\members\account;

use Apex\Svc\{View, App, Container};
use Apex\Armor\Armor;
use Apex\Armor\User\Validator;
use Apex\Armor\Auth\Operations\Phone;
use Apex\Armor\User\Verify\{VerifyEmailOTP, VerifyPhone, VerifyEmail};
use App\Users\User;
use Apex\App\Attr\Inject;

/**
 * Render the template.
 */
class security
{

    #[Inject(Validator::class)]
    private Validator $validator;

    /**
     * Render
     */
    public function render(View $view, App $app, Armor $armor, Container $cntr):void
    {

        // Initialize
        $user = $app->getUser();
        $policy = $armor->getPolicy();
        $this->policy = $policy;

        // Initialize vars
        $vars = [
            'show_phone' => $policy->getRequirePhone() == 'none' ? 0 : 1,
            'show_2fa' => $policy->getTwoFactorType() == 'optional' ? 1 : 0,
            'show_verify_phone' => $user->isPhoneVerified() === true ? 0 : 1, 
            'show_verify_email' => $user->isEmailVerified() === true ? 0 : 1, 
            'email_verified' => $user->isEmailVerified() === true ? 'Verified' : 'Not Verified',
            'phone_verified' => $user->isPhoneVerified() === true ? 'Verified' : 'Not Verified',
            'show_email_code' => 0,
            'show_phone_code' => 0
        ];

        // Verify e-mail
        if ($app->getAction() == 'verify_email') {
            $client = $cntr->make(VerifyEmailOTP::class);
            if (!$client->verify($app->getUser(), $app->post('email_verify_code'))) {
                $view->assign('Invalid verification code entered.  Please try again.', 'error');
                $vars['show_email_code'] = 1;
            } else { 
                $view->addCallout('Thank you, and your e-mail address has been successfully verified.');
                $vars['email_verified'] = 'Verified';
            }

        // Verify phone number
        } elseif ($app->getAction() == 'verify_phone') {
            $client = $cntr->make(VerifyPhone::class);
            if (!$client->verify($app->getUser(), $app->post('phone_verify_code'))) {
                $view->assign('Invalid verification code entered.  Please try again.', 'error');
                $vars['show_phone_code'] = 1;
            } else { 
                $view->addCallout('Thank you, and your phone number has been successfully verified.');
                $vars['phone_verified'] = 'Verified';
            }

        // Resend e-mail verification
        } elseif ($app->getAction() == 'resend_email') {

            // Get class name
            if (str_contains($policy->getVerifyEmail(), 'otp')) {
                $class_name = VerifyEmailOTP::class;
                $vars['show_email_code'] = 1;
            } else { 
                $class_name = VerifyEmail::class;
            }

            // Send e-mail verification
            $client = $cntr->make($class_name);
            $client->init($app->getUser());
            $view->addCallout('Successfully resent e-mail verification to your e-mail address.');

        // Resend phone verification
        } elseif ($app->getAction() == 'resend_phone') {
            $client = $cntr->make(VerifyPhone::class);
            $client->init($app->getUser());
            $view->addCallout('Successfully resent phone verification via SMS.');
            $vars['show_phone_code'] = 1;

        // Update email
        } elseif ($app->getAction() == 'update_email') {
            $this->updateEmail($user, $app, $view);
            if ($policy->getVerifyEmail() != 'none') {
                $vars['show_email_code'] = 1;
            }

        } elseif ($app->getAction() == 'update_phone') {
            $this->updatePhone($user, $app, $view);
            if ($policy->getVerifyPhone() != 'none') {
                $vars['show_phone_code'] = 1;
            }

        } elseif ($app->getAction() == 'update_2fa') {
            $user->updateTwoFactor($app->post('2fa_type'), $app->post('2fa_frequency'));
            $view->addCallout('Successfully updated your 2FA settings.');
        }

        // Reload user, if needed
        if ($app->getAction() != '') {
            $user = User::loadUuid($app->getUuid());
            $app->setUser($user);
            $view->assign('profile', $user->toDisplayArray());
        }

        // Template variables
        $view->assign('', $vars);




    }

    /**
     * Update e-mail address
     */
    private function updateEmail(User $user, App $app, View $view):void
    {

        // Validate
        if (!$this->validator->checkEmail($app->post('email'))) {
            $view->addCallout('Invalid e-mail address specified, ' . $app->post('email'), 'error');
            return;
        }

        // Update e-mail
        $user->updateEmail($app->post('email'));

        // Callout
        $message = "Successfully updated your e-mail address.";
        if ($this->policy->getVerifyEmail() != 'none') {
            $message .= "  Please check your inbox to verify your e-mail address.";
        }
        $view->addCallout($message);
    }

    /**
     * Update phone
     */
    private function updatePhone(User $user, App $app, View $view):void
    {

        // Validate
        $phone = Phone::get();
        if (!$this->validator->checkPhone($phone)) {
            $view->addCallout('Invalid phone number specified, ' . $phone, 'error');
            return;
        }

        // Update phone number
        $user->updatePhone($phone);
        $view->addCallout('Successfully updated your phone number.');
    }


}


