<?php
declare(strict_types = 1);

namespace Views;

use Apex\Svc\{View, App, Container};
use Apex\Armor\User\Verify\{VerifyEmailOTP, VerifyPhone};
use App\Users\UserProfiles;
use Apex\Armor\Armor;

/**
 * Render the template.
 */
class register2
{

    /**
     * Render
     */
    public function render(View $view, App $app, Container $cntr, UserProfiles $profiles, Armor $armor):void
    {
        // Get policy
        $policy = $armor->getPolicy();
        $show_verify_email = in_array($policy->getVerifyEmail(), ['require_otp', 'optional_otp']) ? 1 : 0;
        $show_verify_phone = in_array($policy->getVerifyPhone(), ['optional','require']) ? 1 : 0;

        // Verify phone
        if ($app->getAction() == 'verify_phone') {
            $client = $cntr->make(VerifyPhone::class);
            if (!$client->verify($app->getUser(), $app->post('phone_code'))) {
                $view->addCallout('Invalid verification code specified.  Please try again.');
            } else { 
                $view->addCallout('Thank you, your phone number has been successfully verified.');
                $show_verify_phone = 0;
            }
            $user = $app->getUser();

        // Verify e-mail
        } elseif ($app->getAction() == 'verify_email') {
            $client = $cntr->make(VerifyEmailOTP::class);
            if (!$client->verify($app->getUser(), $app->post('email_code'))) {
                $view->addCallout('Invalid verification code specified.  Please try again.', 'error');
            } else {
                $view->addCallout('Thank you, your e-mail address has been successfully verified.');
                $show_verify_email = 0;
            }
            $user = $app->getUser();

        // Create user
        } elseif (!$user = $profiles->create([], true)) {
            $view->setTemplateFile('register');
            return;
        }

        // Check if user is verified
        if ($user->isEmailVerified() === true) {
            $show_verify_email = 0;
        }
        if ($user->isPhoneVerified() === true) {
            $show_verify_phone = 0;
        }

        // Template variables
        $view->assign('profile', $user->toDisplayArray());
        $view->assign('show_verify_email', $show_verify_email);
        $view->assign('show_verify_phone', $show_verify_phone);
    }

}



